--[[****************************************************************
	Book! v1.00

	Author: Evil Duck
	****************************************************************

	For the game World of Warcraft
	Book! maintains a library of in-game books.

	****************************************************************]]

-- 1.00 First version

local _;
local addonName,PRIVATE=...;	-- Blizzard passes us the addon name and a table to all addon files in the ellipsis variable
PRIVATE.Code={};				-- create a subtable to store our utility functions so we can call them from anywhere in our addon without making them global
local book=PRIVATE.Code;		-- get a reference to our functions table with a friendly/short name
PRIVATE.frame=CreateFrame("Frame",nil,UIParent);
local frame=PRIVATE.frame;
frame:RegisterEvent("LOOT_OPENED");
frame:RegisterEvent("ADDON_LOADED");
PRIVATE.rframe=CreateFrame("Frame",nil,UIParent);
local rframe=PRIVATE.rframe;
local dm=DuckMod[3.1];

SLASH_BOOK1 = "/book";
BOOK_Storage=nil;
local Orange="|cFFE04224";
local Yellow="|cFFFFFF00";

function book.ADDON_LOADED(addon)
	if (addon~="Book!") then return; end
	dm=DuckMod[3.1];
	dm:Init();
	rframe:SetMovable(true);
	rframe:EnableMouse(true);
	rframe:RegisterForDrag("LeftButton");
	rframe:SetScript("OnDragStart",rframe.StartMoving);
	rframe:SetScript("OnDragStop",rframe.StopMovingOrSizing);
	rframe:SetSize(500,400); rframe:SetPoint("CENTER");
	rframe:SetBackdrop({	bgFile="Interface\\GLUES\\MODELS\\UI_MainMenu_BurningCrusade\\dp_nebula",
							edgeFile="Interface\\TutorialFrame\\TutorialFrameBorder",
							tile=false,tileSize=16,edgeSize=32,insets={ left=4, right=2, top=4, bottom=4, }, });
	rframe.header=rframe:CreateFontString();
	rframe.header:SetFontObject("GameFontNormal");
	rframe.header:SetPoint("TOPLEFT",10,-5);
	rframe.text=dm.Render:CreateFrame(rframe,"TextPane");
	rframe.text:SetPoint("TOPLEFT",10,-30);
	rframe.text:SetPoint("RIGHT",-28,0);
	rframe.text:SetPoint("BOTTOM",0,8);
	local widget=CreateFrame("Button",nil,rframe,"UIPanelCloseButton");
	widget:SetPoint("TOPRIGHT",3,4);
	widget:SetScript("OnClick",function(self) self:GetParent():Hide(); end);
	rframe:SetScript("OnEvent",book.OnEvent);
	rframe:Hide();

	if (type(BOOK_Storage)~="table") then book.InitStorage(); end
	book.InitStorage=nil;		-- don't need it anymore
end

-- An event has been received
function book.OnEvent(_,event,...)
	if (book[event]) then book[event](...); return; end end

function book.SaveBook(BookName)
	if (ItemTextFrame and ItemTextFrame:IsVisible()) then
		while(ItemTextHasNextPage()) do ItemTextNextPage(); end
		local text=""..ItemTextGetPage()..""..ItemTextGetText().."";
		repeat
			ItemTextPrevPage();
			text=text..""..ItemTextGetPage()..""..ItemTextGetText().."";
		until(ItemTextGetPage()==1);
		local exists=nil; if (BOOK_Storage[BookName]) then exists=true; end
		BOOK_Storage[BookName]="03"..dm.Table.CompressV3({text},"Book!",BookName);	-- timing debug params -> section, entry
		BOOK_Storage[BookName]=dm.Code:Compress(BOOK_Storage[BookName]);			-- apply compressor
		if (not exists) then
			print(Orange.."Book!",Yellow..BookName,"|radded to library.");
		end
	end
end

function book.OnUpdate(frame,elapsednow)
	book.MonitorReadableTexts();
end

function book.MonitorReadableTexts()
	if (ItemTextFrame and ItemTextFrame:IsVisible()) then
		if (book.ItemTextFrameHandled) then return; end
		if (ItemTextGetCreator()) then								-- A player created text
			book.ItemTextFrameHandled=true;
		elseif (ItemTextFrame.TitleText) then						-- There's a header
			local material=ItemTextGetMaterial();
			if (not material) then material="Parchment"; end
			if (material=="Parchment") then							-- It's parchment
				if (ItemTextNextPageButton:IsVisible()) then		-- Multi-page
					local theItem=ItemTextFrame.TitleText:GetText();
					if (theItem) then								-- There's something in the header
						if (not GetItemInfo(theItem)) then			-- It's not an item name
							book.SaveBook(theItem);			-- it's by high probability a book
							book.ItemTextFrameHandled=true;
		end end end end end
	elseif (book.ItemTextFrameHandled) then
		book.ItemTextFrameHandled=nil;
	end
end

function book.ReadLibrary(entry,contents)
	rframe:Hide();
	local buf;
	if (not contents) then
		if (not entry or not BOOK_Storage[entry]) then return; end
		buf=dm.Code:Decompress(BOOK_Storage[entry])
		local ver=buf:sub(2,2) or "0";										-- get compressor version
		local fnDecompress=dm.Table["DecompressV"..ver];					-- find decompressor
		if (not fnDecompress) then return nil; end							-- no decompressor for this data
		if (ver>="3") then buf=fnDecompress(buf:sub(3));					-- decompress
		else buf=fnDecompress(dm.Table,{},buf:sub(3),true); end				-- decompress - old schema
		contents=buf[1];
	end
	rframe.header:SetText("Library book"..(entry and ": "..entry or ""));
	local page={};
	local xml="<wn><meta><page background=#0000/></meta><render>";
	for k,v in contents:gmatch("?(%d+)?(.-)?") do page[tonumber(k)]=v; end					-- grab no matter what order the pages are in
	for k,v in ipairs(page) do if (k>1) then xml=xml.."<img height=5></img>"; end xml=xml.."<text>"..v.."</text>"; end		-- spew from 1 and up
	xml=xml.."</render></wn>";
	rframe:Show();
	rframe.text:Contents(xml);
end

SlashCmdList.BOOK=function(msg)
	local buf={};
	local count=0;
	for k,v in pairs(BOOK_Storage) do
		entry=k:sub(1,1);
		if (k:lower():sub(1,4)=="the ") then entry=k:sub(5,5); end
		entry=entry:upper();
		buf[entry]=buf[entry] or {};
		table.insert(buf[entry],k);
		count=count+1;
	end
	local entry,smenu;
	local menu=DMMenuCreate();
	menu:Header("Book!");
	if (count>0) then
		menu:Header("("..count..")");
		for i=0,255 do
			if (buf[string.char(i)]) then
				smenu=menu:Submenu(string.char(i));
				table.sort(buf[string.char(i)]);
				for _k,_v in ipairs(buf[string.char(i)]) do
					smenu:Button(_v,function() book.ReadLibrary(_v); end);
		end end end
	else
		menu:Header("Your library is empty.");
	end
	menu:Show();
end

frame:SetScript("OnEvent",book.OnEvent);
frame:SetScript("OnUpdate",book.OnUpdate);

function book.InitStorage()
	BOOK_Storage={
	["The Schools of Arcane Magic - Necromancy"] = "0F#hB!JA,h2rNF3Ag̦<<z04NӤ@@m7΂qa1\"&Sp\rhdS7\"\"g9L'Ca@c7#It2ʎ\"i7N	@s8Xe4e@SNRɺ63_oԱ2(d05q,HiDi3XiDۮ@o{ԦG'ʍ%qߺQ%\nD92FiempS6иXNl6?kc1ֳ{ZRшeVswKPJU5\\$M\\x\\iHҦQQY֑DFgftDbݖ1e4M4dgqttZcfxqyh4^kg@w^m.gwMYW|5'TDD^uu]ZQm	]9UgAy_iZQa^FFhVcDU8t1TXy\\^XNQfq+i^sf:\\S,hj+zFZ]~o\rA*XљihN;0 1KcVlVVdAas-8':bniWDF}hZ?la6QGmzey5*GE=M1&F噁gꔎR|Z qmfθ9liF:0wQEǢ	&_9<e,Al^i7yӻ|an4e;dB,<1YPŎpmG1pR]3hE,",
	["The General and the Grummle"] = "0F#j4JA,h2#l'1p9Ng3)@b<n2&<po7&Iy\"a7I|o9pDY7DU,6&qy@yxqW\r3A,9gt wMΦ5bB?E3in3-|f ;efI\rWco4VI#''Lp2ΔWȳ@d9	5cDnNee&S\000iclul5neY@9d&At.2BdZM.L'fЀa^Fik58LkIݓfTpbuo`W!o8h_d!WusIa/I9McYJ!si璥fPn(BJFݒT]5P}J8TGDdd=yiGtp`ǀrGQgLFĥ HEHF$8F4aQ轄UA^Fy(@!4A1QAtIB)DSVbDauqg!!D턦VDgQGPlM!k Q`'iRR8eFFK1HBipQt_1BٹeS+y8G(9oEYzDSL\\u5GLf;mma4AWꁝEkLaapYez}fqatթ\"1ͮIm,g+TmZKIT[E\ry`(\"[U%KDFavR}ye-lV]~VHs:K$|zN7!d&[)7GaFR?a4F+x5 b88n!b_T,",
	["Ga'trul's Logs"] = "0F#Ȉ6#JA,a<CP(l6L&@g:fI@s8·C)No:\ryhu9%'3Io7vFC)[7R@t7D;cs,zZSY&lG0F (&sctVk28}2\\Mf)έ{S-[,Qqi6cqo7ˤsdrѓ)61L$.6DW?8F4us5k9α&1gQw̌ҝ6SOeaelV'Re[mDTueWљJfԤxwl@l$pF!cxV'BnYEЁkў!a@< jQqUao[Ҏw\\\\uYFmx.cw*FtFMlԱA^peeXL(b\"V\nmͳ[xTƘ5KYgW.BbFHrcU idNy*OZth%m3q@DCh$L忌]V!O[ MƄD-PUFE rJGu69xG~\rB{0_hZdЂ7zafqQ)LSR\\ZVG1mT-siK=M%}f4μDYʧ;*koFfVds%apr0e-urtDBYaV+.ѷqb*s|D^\nkǲOk \r-G,5ED$FäYIk\000L8V,udc%AMZGK!GO60\\T!9Y{N^gYqR_PlAV,K.0txI89\\vJS|XfX쩏z1p@jDe5}G/(,ޝQ,aܣsR:mMURYG~s,UˡhGδsS/C6%Y$}	LE(K&>K0\"°/+6by)0biȬ wKMI6lQA\\+xW`,N\\\r)YH	$%2# t.%R>6,VIdK.ъJ1HB Њ4L^=7rjߩ|Dd1K5P4Ī*RDױM5Yfa:I7P8h\rsFc$>\r1VҤd9K{&CZ3Vq\000uJ#@EIeU,ԡ').\rPYe#͙?V NaqBx%U5,6|?}+8A%yޝH#dB	٪,2̕J5.*r1;i'FvJ?JαD\000\n}ACX̓i;'^VH(+PBsoZaVbQ41fS݊$-	j)dT \000\rbE3	:F$bŸĩ<45EUN.@7GMh\000\\!#VwZC@Ō(+\"7lS%w,8 2WZl\\Yv+:aQe^tI!Ge&P.+&6q>ZFz]Dgt'Q~PG)	έc.+\rXY \\Z3`eyOILYi65WrFIJH-/ړfTE())WVKFO{m3*n&dIa%\n0I$ƛ(vx7K-z5#ᄮ1,b^|7*i0IげW*uV+JzfDo^jQT^`,S(;+rּ6Лj8A֙h",
	["Arathor and the Troll Wars"] = "0F#Ȍ1 JAA9,Ho6e温dSiW(:ca,\ri7	1A=7Dwɥ3ag4JFYAe9DS@o7EMjQr]9Eȉu6J-5\000lVf$/LۮC)a:N*BA<_*6ޣ1zKEMكM6g0.ַ04f'l\"s0l}6@t9LgMqqlJ 8ML{Uo<,R?'9N)gmAOQ4IƤb{lPЀi@ӄ<OH^QC^%`BTpe6UQfhDFha{ bѕw@-C-:EF'oȅ&QiU`ȵYșI\\([z=IxeajQGDe喝fxGQG\rxE\\dxoQm_~jLVŦս_߉bo(Qxi.@K^dQ\\xFű*EDRZn+iycgj4r%EcflV jZ6]JUΥU&XAyӊ$<. Fa;\\6ܔ`v_!1c'AҁOYFVxUU՛y4dDYJ-pѦBgʓ%m5spSYёat4ZFwC4Υg;e(}XUq!lG5@'0RQb1 ƍqofQbEOZe)BĐmDeca+0kոT:!)RG6\\DXˆG(A)||]5vP#-yڥEue)][S92nRY]gMx-bMFeSm؝ѹ<\"dlnt@d\n'75HBCHK)#H	;Ff6&\\bYê-sno,L6\"~f8f38kN@h*pn2ZGd푰@@K$^NkN^AQH\rlEXb=/*`F  v_艜\"Ќ{\"'G|!8 GhK)wp#0Ck5%~2@N?|b7҄aWYZ}!:Gw2μ\"qi<G<jq 2@Icc.\rAc\r#a}p@A\naJi$}=kY;948\no%.fq.ߋc@ȜkEX=\n4]6PN.#')p1s`eoHbyUѩq((և90e>iΑa>ԧ2çC}8p\rSQ	<uбfoCXP3[%iN*\nhAw	%琵yl6SMj8g㜓V\nh JMB\n	*ze*'ó]Ntc!`Ѕ`_\nӲG2y啧G9jV!hi0{sSB#93ĸ&T4\n˘m$/b\"ӻVBc7%I|ie3-\000&r/7,N.1<7dG%%\\IM<E7\000	<ZTM@rȹ+;gu=-NP\rR2y1f%n\000y2u8vPa!WH阰icJ4$,Q$8Swq)9zzC(;)PzFKr͏,X4XÇLU(Se)\"#+t~Z+no&g[,JX^J@k(P	vWsv2\"i.UWTJ\r$P#)MbLfF]>E\000[T:kXrliQ>ЭV_EʇThA{	-'*0J?k'A:EtA!žf/zb1Ya5|]\n^Rr	y+C4=ij:N٤bb:	]{s,D9$	\000n'9GoFJ'u\n\000",
	["Aftermath of the Second War"] = "0F#r4e!<t7M#)dMу!v2`y\rQr9\riLryu9YsMSaJSare3Aa&u\rT1E$h0MZ醑O5DKFStMeha릃IYF̈lRYflĝN؂uF\rs@[90xf;!7A+\rgeAfq*ҘLx`E/Y~͖1}۩AsNJG6p4}ɻ%<l*lY&	WQz1FDY$Rwa}5~7(mj1MZfu\"R%qڦ!&|R\nx]|խi5\\VFQc}dsx6PFi^9,abVQgJJх)qIJP=XGPbxe4}1kEqrZ0ƅCcR|'RѽAJG%Gti=!Fejڨr(d~&FbWf%tyXTy^*E'YэPnx^kZVה~~ĥәcG&=HzdRapR6w&nlmsaFAZTaS@P'G\"3)PBёNUa֣qyr]!B{kqTr˔EUULpMF]uN/H!tJʒ)!xoBKՈkҗ\r1kj8֟bS4+JThiyiAtQҤﴌiDD\rQK-GrE,d,Ql[ļaF5bh1S&RY}Xt6bk\\QrfQXQ˂Fl2q)|R(pA#aA>P©^&:F*fyKƴ GKaOd(h(O\np(\r\"\rA>iI\\}Mic`lڠ\rg<21܅ʱ:(`	%FY4 ăg(I\n?\"Z	c(0ӽrpI'syc芬K,kXIYI]0Zho*$!%E0,Iy5)\"z`crqUI]flc\r+Hv*q50bIcx:#U6_0!+FQQNgD>8F9ItL\r\r4҇yv,3L4C(\rr)(|HbÒ\r-± sw̒ &.M%qC(feBXYp@&4Oip#}J#`Abj}',ѕYq2ˡD@@SxA(\"DW8g?Ga	BAb8eU CM	c\n!Ԫs܌X+J)pva)٩RPPX{8@",
	["Empires' Fall"] = "0F#p1\"JA,h:ł9a:qq 7#y DiiK9u1Nfp4ţ3lO n%G\n2O\"d?!NS`aB.3cyʠ(:)yQjN4g2͵o6IYbnM9Fa5\rs7sc3*SZZh?3*K'*`_6\rvRY=1H1Ɠ`o7G3}33UQuX[/DE)nu Q3JU3w& VGU]ryGzQuQ[aFq%1IXzѤml$` f]FqBD,A%%Ɛys%zai_\000-ca(Q1!]Dnx[~cuHXQќKEn;d{iIBFn!oƱݬJb{EIEq2KaٴKZ#DrZ!:H֙3juݔх\\= lal|Qm!VD6>[{u>rD,3BUWVhFVEĪ#][.Je0Z3l[7wlbkF?Hў`16 \nK0BM0 \\]	r|cMӸm~z $lxU衆[@lTbnrBie)\nx-%z8NGNבt!Ġoƶ]oEi\000k]\n@D1D^kGVQ-Kl	fUթl\n[F<sH i*ej.FDkqi3MRz5wO3>kC4e_%lbAɨծZ8rQ,y5kd)9N\n|HUҒr5eLVJ{3&tbK	q0f\000$21WEݴC8\000E!`'e	AQ\r	XnDd5	3pHpI)AR1>ؘRwM>\"`!EPє)`ƆPʳJ<>'̥dB9b˛|l+p$aEHlTGhHj0A\\4D\npH1:HM%½Yp\"D`!waD`.of40{Y8w)bbbQ$bKh\000: OI'^\"",
	["The Birth of the Lich King"] = "0F#Ȇ8JAT4qi:ł 6gAw2S`Φqg,e0\r4 ;NF)8oGFa72I@f0sc	Қ 1j2Sau23)Ri:Z|4	sc=A31EVy5t4+Ao\\,sLtNz4K)qem/F6Ap#x3`aimg9̧%:\rC<2S8a-wb7\r5czpYurR6IvRuk^1EAcIfQ}4LrIe-X=f$kQ<YU|wo:5YEAvtDeQQ^QPG^%\\dr߷9fyUYT	l^O[ԩakE4PT5GQhriڔU8QGca1s\"eeOqats$p7A#;VG!Jsobot[]TyWꑵk(W#8bGfg7^L%ѴSfS5E\000lGVdZڭpBt,WGSyhܪ[ap[]u=nOj:P.̀}wjup9;fVf_ЀAH,S1u$jlizYqx]'AUSĊ;DܳeSpR-dȑ3fq}^>ZxprdaTBd/KqKs]4p0!%U'Jx$U9R=mLXEeOCDfhrw E`EV`5rnGMP{UFJG&j;UnhN9䠔>FosUCJ.-HD%p$k܇() T\"h)yN?sLIhfL@)'jXJ=x2pt'/`CRw-Z&8SWS-\000հ|3,\"??E䐔F!DNГYZ&,nG${/̐vV~nЅ~;0!H ~h9`s0(Gi#&*	( ]D02TeSM%)$YW'ɳZutPy05l%Gv1D8J d*,eR` 3\nAj(!@Vjނ)NI$\n;T$Ø'+X6(	 <DE55XR 4ZW`ѳs\rNy2I<U&Т> dRex4GRe])(\000%άL:Yu*-a9EYq\r\\=lh2F4ۙ#𢙰@Z3rU-@JK{K\000`Zng~n_1b)OeR%åQ%F$u~D.FvQU*@\" &ωERW>QUY0!Jfk|aq\"+9ڶ%yтekaH@_keS<cIـk؃g}\"MS4\n-B3¾H±ɖjKac8!BL.4|\nɂenK_ZD$XGO#V	I\n\"Qs;51:bhykEyzb=T75L$v22aut^\r~X/IlB\nQHv˂C`IP0@]/i>!DʪIIOүg_0KhIy^e\"6|bK-Z9@",
	["The Schools of Arcane Magic - Introduction"] = "0F#h5JA,l6f3Al9\rag43	@b2e2a:JLd0\ri6ORiO8PFeyr\nrM`'&JHf!&u9d L蕜`GQcYY'I̧{ї.cM<vX4kr= I$ҁthgFEZ)i07j@nbh+	$Y'PRk|so1R-cICłnL=*HXdnT͚^F&0ZDD]Ga}lJW a)GHoTav_n,2BH}ދAuX%2MṼՑt])y^!/LT:W]a	yMذd#u:ErFh]Wјfvt9əIɱ́euosGYygY~7ᅺ]Bb'UfZDXPh|VhQʇcwIuEQwBe(eoEsay]`,zddqFUHq\\w%RJXTj5%a ANp)rQ0m1Z\000w%c]=ܕWطRVy)w`fI.ɮ^l[̈́j>tPPyG1`Ի=bUᡯJDnBJfylr",
	["The Dark Portal and the Fall of Stormwind"] = "0F#b5GJAHL7\rn2\r9M#@r2#qgͦQ2L&4X 9Jhl70i3M\"񓙄4bq-3$&v36VIe0$̞S+7Q)=ƕMmTeW&q8R\rNueCDFchc%\\O^0Qn:'3N1M3:.+̙Zn:f\r'Js#iRo/D\"QN<j9\"+ #a`$ar֕bLWmRB\rA-^T_JR%VmFq\rU dѬociQlRegYdYN~nG6uFRyZ U!)avzED}U)db_VFU4M\rjK85e2-iaYI\rJEf]) Ea<r~Q)5MV3kSD8kc|!u%fJf̣y\nUQ<FUV1#GvxGBqG[\năGCa	qƴd\\Tb%{ֹqYxkDlpY	Lt&MRM_\\rnMF.FDp\\04)orj7t(J\nSQiZX{n`A.J\nWx\"Qs]T\rD_sbldMu\nomJV3\"I%yY$TmKWH1_FnDaLmLYF:wQ\n\r~]t\n~P,^rIBaY7cSe!q\0004\nGxG̶}uXv=LxR\\EwCP7FarT03)AbM('TY+)Ƚżk͉6ˢa҄JlV6H .arCc2`H%UJ*\"ܩ&N1(>4R9#kiLc;6ʽ[`X+\rbD s\\b>#$)5.AEpH\000tðhT7@zH\"-(Lp'FtJ8	10TdX,Gm2(n#(@0BSaSPɢ%\"T[$(XGtY&\"U9;ู\"%If	9 ESn/JLh1aPOЛ\"w#\"&)yڔ@KDM;'XdBG!=@ȩd! HIZ{ȹrFOi :2KKaUoQUH.JY-Gbf)kxO\n~?Fo'f=\"X{a\"55J'xMrPI0LDJRqtU@Xͳ5xqdUU\"!Ѵ0m8{Alc;V+^nT\\<ZhƴJJu*T\"DڱCoA^q_C`c` \nh\"Ǿݠpn\na4Y9(sIĦRG.Txa|>	M%\000á}d$`rC1J$2ٴIbc\rDTo\r9aa9T֜y)h5TdNE\\ZL#N7C)@kXfY)9\"˳&ŀya'Ad8?wұbEl,0Tzt+kf4\000[N\n)QezJS%JG\000HRNȆІ]rȔ@E6HHJfXNr1Kg6:+8Ԣ5̯6m#l4?boκ!W,+@3U.$l6Cܳo}yHf*AI;J%?\\#27uLEYd~Η^I C|y.D\r9!3jg(Pd$>QY̦jռy4u^&Te4*d%*ٗI#VY]4y}}O <4̈́D|PP^NV6	b騐\"*^A7=gV4W\0005RMH'8}\rХTJȗ>M{ogz<xԽwU	3<EM:rGbz%RP\r,ބwPT49`4^/\000zv~o{\r '4h\nġH/˱JsJ\000X0ZG$pV(F1^WFaF 9w1k?<y-c/>oESyeaq\";Id?1V}\"PRXI__rqqz|=SJQ8ԃ2&R*G'~(@|ƥX CaPW)s(6CO:%! Wx=cArSPSUSa'}\"c#;\000eE bvBJaK(\rs*r0'Y$1&I¬oSU(Z&TdF?phX0ǊdvYSj<.,w4XZ>47+\na~G0}$a8I2Ko]!u\000gGUN\"A$ؐ7~%4#U64pwn4M7J[I8eusG}BpBKb_-m!4o&a0hUH^Ad;1P1KhSuRP40oC{.%18q--a%3%EK:Q&/:jB>g&0g(X¥4w -6ygHByxEu#T[XkhFL@pjI9MBk41&ĨN{#c>,c4WgW48ƏBGs2&>2}-fv8;'+bVJKOQ!A",
	["Icecrown and the Frozen Throne"] = "0F#nDe!<e9(o6\rsI 63@N	F@c#S)$oOe#1s\r<@o3!D1D3u3,<ZL&ta1N>N7g*\\ +܍Z8r6֪*Zlg9Fb!l<ɢYw[8)C8e9NF{c)U!S6rdf\"GuRۆu9d\\n F0dI6Qb'3H8dNƚڌm`S[M]!oG%hO5HEQuM6\\'e@Rա8L6E.ioW'a4\"RٱQe~!	Yc%EEQ_ФJ$,K6ņRT5bYDcqQFyFtuWtfEUFQDܨFdG\000 oy&Tv6XxW-T_48JS\rQqa<e$Vl\\	th4!ZVFT`f{YAyI]@yHztGAlUebWXyQ|FfrI6$AHUN gER\"8iI0Ds_YLfbQ[UAQ.{-Ug\"\"աEh<w3)%vKd֨|}WeGeƅL1UDm+0dF!ssQitft|HZuZ滯T3EdzPzٴ]DG\000gH*=l҇w&TUGJxl\\Hpxs>EU5qgI$!ەRmpu$ٶ{2X\\~KG=L6!\\UwTbCq\\>*`Q9uCNx-TɾuKldtc])ZEacWtoypVld_,]ϗX[8bLɣFY]A\n3\rP뭕\"HRZvP9\\w\">\"*҃jRĚ<'&,̋w&RRZ$XRH`'\rA\000Ĕ][Hw\\$$]`;ؖʈAMD|L9U38VaV\rm&FrXBX^mOa2v\"+I˻\r&{(l*)3ç\000!ㅇ3D#aLA7EH\\]-%`j4(U]R$ӣbtQ*I͘fk;xځ0ojKH[[H",
	["The Archmage Antonidas - Part I"] = "0F#rAJA,h2fq:Ŏby@m01!y0ʄɉlM9ٲ2i;E	41A6GI3,I'Atddfb(ܢ2lo:FCk6M;!a1Lc	ѭ!\"e\r(|s֎KM{9_Dc4XMB&\r&c.0_8<.p4'CֳBư	e9^3,W(jE*7:\r&{lG#<_5 CfhHfuetAEkѥegҤY1dC4\nPCQrHoGETDSuGZLRڈBCEHMIc!5tj^Loo^1屜iWZ1BAYG( U2GyxG \ncFhu:߁`V6k6yKbunftird F}U$ޒXwOY`BD.u~EwFG^FVA1zxiaQF NJUh4e~dc`WHAEEQ%TXUx1m]8]TG`MƑqglyo:F	!quLRQCasnثGJu2!!%\\ǜ5jUe$mGEw; <^ƆVU^U@2p	Y)11&\\rHl.7ylþS<bSV}}sM ZكSFqZ[\n^bT-IG6n	.LPKty|YQwEй)7r\\1*	z4T\\eֆEML*\\X-efᱜHA]*zQqs0	򲛑tXǭ|`VJ4euJ}XMyb,L\"oHjU5Ud^g}lZFБPC1WGBtY7$d3g\rPݘR&-\"!7ŉ2Y+Bb0'D`eE㫁Ho((dz,3)f\nsԈj8j!kT3oUHBDB()#.[	Ҳ\n'TIDU*:ɬ&N<A-C\\BKYx)V\n扇4#Md(q&lxtD[{<AHXy89КsI&DFDeҗ C(NCh\000ȘqgDhnfdt{!`C(rJC7h Ѥ&059e[%VQIv0 3DՓ)Rɀ#ot9>(m-A|* ќ ĄΒp/,GwN\"ԶGd;[yX8d!$4k\000:d-ph^\n`NIM\"(j&Ԛ7(	",
	["The New Horde"] = "0F#ȊC!Pr0\rkN$Xh0MS 6LSqr<H 0DCye2\r9a1s[/6QCxe1qCAA?;̥: 7Ε\"d2SgWvTMֳAD#1Nt4mAKȂM9x1Bph:#ɴ@ҐbFɌˋk'M\\އ'1N}BgۜDSufaLS}X3]eW9a*մ9FYL!rRtW]BQeԵxwr?t5]Q6gW`)5UQ|Gy~!>\000~E?P\\	GRUIIQusjFpNNaD]7\r:r^W#T$bԴELTqctZ$jM[Gac|_5kr1ǃV:NIuJ]SաgOUpai5DeY\rA]!t*˘ǁL%a<rQG%axTPFٓq^1_ڵ*td-ݷl5NYuu6~UWaga!ΝRU]zm敮yњ!M%5LXZMNZՔf\"1lf4lL`qP-Ÿrb^#BV0pik0ؤRޘi]4Q5DGk	:bQ6u|~\ra&-m\r!NTFcxh1۾ТTީ\\1G	ṋh$LrOQA# ^|WwIm:E렁uƁD8t3達xf[hAv$n6^!]oc캷H$`V2e0Kc(eJ8W[a\"}'Prw+0j)\rme)~uEH4K*dLXt4Zܟ	%$ cgᾂRKdO})R_1/i0JFF+J*D2	-L5<{J7oa.SI90*'Фg}F5@UcW[ᴺ;BĜcS]$uf\r C'sV4Vl?GiHIJM\\X2p1g08RXY&FfvAae\rû.VcǵOKT0=_MBrxn4]$Z+pA8$.y*d3CP\\\r%.}i5\nH=ZSW',O%ONAǳ}bsah\"P:dL[\"%6i}Љ_GV4r\000NKR\"Aș\r-0嬢j'|PZ+	&}RH\riG SMU@rНW|6AĖ%o[\n\r\rVEL\\a;kMy'E=bzoi{!ИUP'$8{	)AKAA؂\"\"F'\nUVP>1iG8T=Uڈ$v>U<ўR@9Vf$sŏZ!rZR\\0ӍAZ;08̫b2h(֔:ʫ,RDgy'-eVQ-dքV2d1)V[}ܓrFah\rG2~á*'	Pyޕo\nS2F%#kY']H6N}Bao$FΨsa3\000tpiYζq_G3ה[Y	r펦ݛ05ſӶsO&Qo :B!QT2Z**HkQwJHYR\\4?uW^=DDFA44JRI H\"v\rrۄNr!vվI|8hٝ(aUrcK<$Ր`$nMiR	!EN2n1)}_S2Ph紬e⵶PnWrg(D˕)ްyC%9IQ(R{n1/6eTz",
	["Beyond the Dark Portal"] = "0F#l2E! 0\ru7beGF)@w23VJs3bfp%:H3C<v> 8GH@d'izhu:IH 7TX|a8iɱSH0r0l'!aIz)5!R92oFHg4g<&Nv>ANbqXv\rs1L;n[/c	Hw)\r\\ 'JDD8f7čAlNXߜGM&ČwIZ$^ui%lIK_VSqi^ǁauWA#GInMGr%!zVoS;lw$dG :QGiwflľM17ZHY9i	EHYSN9r<Y]B	e1^TIPnbJ@Ȥ0nx5YtG'MDx)@MVw]es[A`UADTQ)^ !yHVH^TAmdѾ]ו)d5xr7q[zBa|DF<L*sn^1R DGyZ VqpO!	1͂OxMTqgZ\\MG|OvOQ&_+Ihr\nQ. ռZ͔ddm[Ɖ&\ry&FZG'Q21^Zj9Oj v	T)rr:41)}jmw$f\\ށZ{Zf:l)aQQdEfi3qRQ짚fџ'=H^Opf|O9)o\\v_DrfyqSI,%`%DjEu[eٕ͢a#iHM0ީ\\lrˠ+a&pjFӝMFhV_M\n[?L0_%4e6R\000",
	["The Green Hills of Stranglethorn"] = "0F#dCL% a+D3n:L	 :\"Gs	@b0r|s&Ӏ@n2(w0HhsItG:Yi2\rc	u7F3i9fƳt \r@h0FS)&a^sIiPuy@fhbhb,bv$XC83,FY&Hq<e΢),DYNcBu9ͩg3y$p7Γj{fcd#\"{z7wA|ʆM؉$9cW\"g6^tTo6PmmT7 ]֕wQ恎Gy4\nеDU\"C9C9![ա)S!wG}F1^W6&bqPb!^WdhZTFR5;dAo%hMQ{Rd G$Q2h EZZeqo6SGtutXecyŏ~^4qvfI<eB;BA`vQpN&&n|'YDmkT䔝E]aKst\\(ڮIojsq`2\"ѨeJȼSQlielԊtTRzkQ*eo'MM*m0Y1	]c)p mgi]Q\"E/SEvTub*tbA&bf<Hdz&;TDwo#	Reԝh &^cbt0IDјemx_6s>L5|r<\noD'y:]ڻn̬hd_3c(XMFx>F8]tZuiؓŁiQbO-'9_x܌{&EFc̒0pZFԚw}4d8s;q--vDT\rےJN9BL\\2cc\r\"+biT3i!$$J?L4fXIk&焐ea\"+L83ˍ9(MB$Xa\rdsnNaG%@dlN}\rVxbǌ\\<D4nCRV'`X`Z*0'j>9\rFmFag IB'ptzd$~:3¢ع+3ui\rGEcC5@tacF<%fgId䝒cNC6HgLsWu\r`B|\000#ʁ(31I}}x	Q$EEߑ)As7*&Ԙu+$eiJMbXA\n*D\000(d2Z; B A(yl	_FLay5`G*bJW5E6IBn<#\"s*,`dz8مu)F1ȊS2΋ڲ&e6e+	n;ᒓԣA5\"	l2ofn,T}£*Zt\000*QbD\000*5U0%e,_6&b,	HI3{4РLp9tE?Q.LC.XR&b|tKfm$&x@	qiBa+(1&+Tِ4[\"s2\nI]:d4j`Slq@ɽw0b3m$J#Abv[\rԓ!2PP˾t-*/AȔ\r&UvK3UhZGH^BLV*$Dmf2'\rD5œJz4ЄGOo)cJ\rl4\000`_!3kKu>\r*$\raf\"[wHR1n\"^Ԣ:e*LRyɈ-#NNd7*T`f'\r#)?bK,KZM4HS8Wlp\\uż)1q\n=jEN(vQT/>a<[)nl2\rE~LeTr2Tey3ǯLI\"Ġ嚌kG!5̘N/JI q5C*nNQ\\Hn:ۓs/11'zVv;ARvc|rx! GsoebUb%VDv+dbD+.#W!<ZDbp~/p;uP\ngA!;%^(H +S|6w^(g><4-O!oc%-ESqkјt1wDB3G!83QS+U]uZ8Wfg Qe2c47ҁ4斂,\n@H7ǹBee(:EA.V׋3F$$U/O4bGCu5D!tE[E.pxMBrlWTaIA)llYu'f%85{mRyqsF*$DbT*O:Q*HVhY!RIH12pvqHd(Y.6(?B&2gG?)Z\\a!v21VRӃf1TQo|cD(tJ\nG77D!ALrt|.r!r)C1B8(Jeqs7Wa`FE:(#h~5B2!9hPr-ay9TFolA5O%8Cj',b!P8//cC'Sq$kbWV;x$+|\"#-LEvdKҋ}aņ*Qz\n@BOg`]~edyzbcRc9aoi(VPS I3*P8Bc =8?*{񡑒p (K%E(4vaj@F0U4s/u;ku4/S	FK,+W<ƚ\");##ՍY(*2b,$RJ#16+7A*rYI7=0 $MaXx5qx4UMRBbZiKf>H\000gf|%\000bz0p(3'e< 1#Caww5ņ+Mry+[Zp.q}.,AU'pa=5c\\:)5e	@<AL.s$<%HE#I9oh9哑!QxK90<v*ld:4,9&:x)XBHXq9Cw!򁀹qA6-qa#$,&|QdRB(F9t!Y>z42x:[)BOw!wI6LM\"?e/-!Qh1igZQLnQB]6)F~FXdBcf9VWbCsBBJA\\c+Q`%v7ݜѣ,PaCAgds.x!{'/F2!AncҢkhs9'P@oig<{*xBOg-/|\rzxMbw'!nlѫ2Gɇ:R9:3ՊF+!RYs 7ppax)gvT$V=2b^YaBq84X2\nCb}uŢ;ꙭA:\\2\000S<aBy1WP&:=%%!8,Ye{X{?#\\9yg@e90iyz7C'Ypr=T-&\"tx:NbտS&R!~(_W#9!!'R(670&oXDq&cZ##36UtS'q[`@j7)A1\000sedVkk%(h\"H: 8 VzAqG}I/g!G#X]1wA<+V8N>c[XBphP9jYr!]ªJ\\;A+aq(g`T=%~BbQڊ7|$I*zcPt)QA8KA-XaLIl$ю8ib;wŲ(Qu#Ø)U]%yetȔ({cb5!R!J*# bĉoiF(V(:RN8+7+#9\\lUrVV!FA]Wa!&Ò}	%klR54FYtI,0|)WJ\"@bd	\rfM\"ۛ|ȣn6YX\"r<!V3tF^P7GCph~lTDQr/C2q2X$#*{mUqbYkcDhtVS<M\nI`nwŢ8*U\\F:8Xe*c@G/QK#\\-Aÿ</\\5e792qqE!!ap&mE}x/YtklFCVs;CMjHjue(`Ift!/јi[ėx.rUVط@V9?O÷	J !1(*u}#9/*vt1mSQ<#%F#-cFuNB|H%O>JBc!_~7QmN+:(yQp~@H+@@JG#5SVȲ4\nLr4]'7AxG*xyUW~/aV`yƳ'FPm ڪ@a<lo Z/=P<&rr\r7b1HvqLZJWevд59(Ax^y*%s)JY\\~,)QoOIƾ2G ay,$!\r_z G#y=g^*i#5VHfz3HN'!-*6p 2~;!Nw1;!}r=0X;,[ rEwF³	&>QXr溡C\"c͂ZsQHB~@WYW%0p'\000G?ZYwGeyNs͚D\"kt&0KUD\nQՁ- DK<M11$@Sΐo%zAP!BOP7[lXz_'&i@DRW*tscyAj'4:.⧪H+MQ.'[K[#$A.U]PS0J=ME=lhFf6f;3dB@H?\r\000x8KB|iЬ:0A]AoF$u5E\n/eh\nUOlRY6e~מ(G	MQ{Y z.!6H&wM-`'\000ֶ.$	IH$(8\000 C]VQq	35ЄI̨DhbaC㋅e\nvDwG\\ɷCTt/qpnP)5$/y1Ac.8! \rtq([].xI4Epϰ\\'8&ja<[_I\r;ޛ>X`N	HLQpO1TF(%d	~|(`\0006$	F̲*G)ɹfq#eCk#-WThꊍI`n#5 j\"ԁNЋ\"\r[r\nU\"\rGcfy!<@\000|Bx\000PD\n@/O`$\000QMp@Do \000T@^ \"	TH\0000<#0Px( BP@8)1KN✬*hzH|\000ȹ8ac00",
	["Ironforge - the Awakening of the Dwarves"] = "0F#nAJA,h2s	e9#Ȁa:NQ1c4ΆS i:3A)3Si@a7KNgCy9Ny֗De1D\"9Sh3haόi1'	iG(ϪTcstYY/*)bO-.|N+HͶ\n4s7r5dۂO\\$fp9e̦eri31+.5D#lcPD@M7( E4͇PzFf/w_&	ፍyBs=1^WCQtWE_YV69l%|nUTreYFu4Qp06=ETUqyCTeJ\"v N1?VXQMdDc]8IVF$ QuaXй)D,CUU=nلI#=PGeQRR_ռkUYQlu\"s-)TPkW$ɒ^E8!ռssvreFQpUZᆅI@nA%FgtFE`ܕ5(n$U.MTYmQrUaE%vsݪ\nXFVTUsU$lѤm%Bъ^|Vuk9?S$-ZTBpfZlGFDfXE2oƴv-S]3k:V_sѪYpQݍkDQJ`sQF\\aKt\r]hy#H(B$,W\nJME^Q<WnEJy	1SOH*ڱKJokȭc&3ju0n3FƁ.YF~e\nttBh&UI=5µqU+.A$kT~thכƁvu=HuEB̇{=Y(TIFtwD9?2O&EB ^B'9UH	2&M9̱Nq>۫2T6GW9x	y@}020Ғ\"/'DpAF5.SfZCI$n,ú'pu9@@tN\000rwF*F\nJ}nPE_1DM-]%XQWFxW^(ʂ{ըp&1)F՞)\000",
	["Aegwynn and the Dragon Hunt"] = "0F#Ȅ6!g;Mu6)rh03AA(\ra1\r )NFx^a\r.KhI9e0)jS.7iaۣ\"@QS뤦&4mA~c-``&kٸfxYi9eUSADykF!U7)&ZUb8u\r4˥E\"ѴU͆4wabyq9ʳF3)ο?7O;|Ar␤\rAQR$]jMtnU\\T\000FũnЁ1HH}[N!PgmAnX)ѝo={tvJT%@WxXf*X\rj)Vj&cnw7G1QS7`kFIg#ayƑpK!P'_>恢\\Qjs^SCQrUVluƺIaf<xwa3`0cr|-a`S((J6[cp\"ftiFڍWU-x!^~Ydnh\"rG}O 0ؤiEmn[j9faQpE.SG9nI١࡝\\e*lrFBG+a񦓼E	Wfie\\4bh^aI)Ɇ\rUȘ)mRpr\\E~F(]pkof!Ie15fo$Xrtj9LdȒ3ԱgIRF|lnT 0Tѧp{ewfLfX*ʉ|-U+-m[o]]h;UOVȂ\"X_aʢua_]P7e3rTݱ}j-8o$bXMW*{VPz%T$E4W'kpt!}EfhCp|6Z.$ed4 !H\ri?FYa\"x1Ϳ4lIi,f5/'Zk#>+87PnL3[ado6)L<Y<L	pBGUw&+(!2&<،e4ștnT9>gO |EKƶ<^яYh*qpk!'\000̑*9bJTȒZh#y,}x')\neI2<$Iĕ!X֝A5#$|wQO&=Lbz1Lh[T^Ui#%E\0007X<!+in8$*vU\"  	!8tERIb8$@[+\r1\\Gxx!wTZ\n	2Y}#-ui&h8Y;0%(>x2YGbOhͲ\n\"PzNHC\000lp-w'_V#UǺ|ZhD4SE-T1W*_BHGLhmB=E)4]W@h\\\raEYC8sAe\r\n1!&)FQ5*W*dֆ^L)[QL'Fadc%U8o'D$3O.uqJ&sDX]/z.ZƖcKL'ڴTy48t-<\n|'K?\rA (I",
	["Journal of Archmage Antonidas"] = "0F#b3\"L% c$\ra@w4u6qs:LFtO'3),e7NbE@p99RCIa1EDo9S)ub3G0&`t#3.4M}aI%׉qx\r'C]5LeӕYM%ł2\nFYYɖ9,A.3H61'	[c:C=f%ǈL A@X!,4b$|0br\\\r~LdP<CWSE[FtC]F1LiC`2w\nmdaSA\"L(SG!(AdIPRGQtXTcId*KI[G%䑄gZ	B5 OEc5FVV@Ƹm6HfHeѲeSXe'hwou1GelbSF.\r^DuZjTM,0rxFbF mP5U)lr;`FݓQѱUNgRQZPGGvOGC`)vhlD09D(dٮ6N]a1W$/FItN,VuS?L2`ˍFV)E=HR*-tW^`xr\"axKFJni^g4uƪL)Ed4*FO+rѶ	ֵueơ]ƈ.j.l&|E\\ƙl̞2I)5nۘMF5'lem}cӋїmWKnK$gUa,X PGMa%ugKSDUL<oLTwu%dӄz61PpT֢gG\\s	n	-Hqw2OG:CUDBDăjI>`6Ex-^>%!5\\^%0BpSMf$g(BȪP	gX\nbs1IS@	ȹ)%XY'tɉxTAéF\000ڣu4e1' ,oJX+W`n)ۿ2h 2{C`o$ƣ=c%XlHg@L=\nGL!Cl=)@Dn2[` Z,ʂC)MҾ- $ ;Ɣ>a\000(&0SI1	uiDR-X0s<uW8,堙S\\&L-\n!l@|'C$ȋ4fq1qFqHu4!#P[CAɠ|?A&(>:FZi%RP	#4*`萢_WK)e\"PRT@U%,鲉 6\"po]di0ݲU'zQ4esYfB鮶q$G5(#[Q&Mq\nѣ6!ڗ>ct$H1O_$l䤩F0C,Jt_0Sέ}`pΜC-aK\"yzi(U_AHun PG\"VjrZŏΒ3	pNw/r['ycGK,\n=Heh-d!&tB;Yd&\000I\\۸Py$)5$LES.)a]m$Rj[[Dj3£,I L1ص4qVP˔1$AA~vҔS(-T$ܠreQ<flcD%epwJC9!ҴȈ¹g*aTтQE՘b@Ah	Z[y(x*XӊU1sl\\1&m( ,zTwm$S6s#{hȚLDBAltJ*G\\]TJMA8Xvӹ\rǚI\":ԇd2SN$БUD\nHj,cA5*?YHjo(d\\$=#Ydi`p~DIզzʩe_sN㷨AHLs]+bq2H7GVʖPEk+\n͆Ӻ3(`fx ;gt[\"έ㢓rJwtQjc}14EP'Ӕ32D._dͱjФtͭ\rP/af%t,D\"H̤v\\6pˈ2=YhR$t&9'6Yzcy:f/UER_ >l/SpA6B@eU3*-*T77WI'B,=|Rybnq6V{r?>[ !fb\\lx2<[<&&Fb=r? ?\000\"Yq(/ׁ6Å#e$+61;Yld8Ǚя!! 4&1F-.=unw:d*~M?~YR>r=@ zQ02%Չ\"_UP5yJq$ P8'ByB\"zG!ag`n%ljcEY!$JEP;<2rKx!\\HQ&qUD+1\"uQxf5Ew:p?^f\"0Fqv邔k\"'seL!2Ic1sK0g4cǷ:\"_ usZB\"@57{A['H5yY}av&XMsQ0yR\000D4Z4qO?èy._vG$P1!ouARΊep:wNEd#H(Be0 c=>W1&W&8-5Rr9w",
	["STAY OUT!!!"] = "0F#p7JA,o:!dDLtL:36Ee9IH@r2MlhDhYB1M1lM\nIvn3dRXh4ꆓnFqp6F̆0F|3M 7Ña4,D<b:eoƚ\\h@kF8kM\">4rcشl0Ι.b\"zg<sޕ4F7F1ɇ\rʻ_]l!9	FI\rيr4ᎃAfRUO.@$<xt4bXpFtC_QpYB	BаK\000DWX8pvPeAX	s]`ubRSH]WC)PF&RdbEQ5IQuZqNFEtHwH%wSV?`4!с,fcFAii\rPETrXC8\\bGAQXbD#u$tgaI\r!gEYQ$X!S{VюXFjQDJv)6\\f8])kGJ9Mݝٱ!Z*N_IiGԉ8ӄdwTqj\"@XVyf\000\r\"`tmhOnm!TvKZڶQWE&b-IpJ0{ᗓM\"èI .FN\\T1l Lo5w^ȄTMbgW-QenbN\"Ey硬< <wF\rF&!B4:d;4n~-P1۴Դ\\e96asrѥoH!&WDmDaaYT]\rNFƕ7hZuU^X%8t&q )P)܊$,*xk>Z&Wi<G|ɇ@Ph6\"#\r@xiu\".kYH^k*OvWOV&Y(l\nUq0`X)o2!QJ\r%ܽWqM5gbUg&wzJca\"1AXnMVdծ8_l.ZM6d7hnaD\"]ݺM0R,ނ7PqK@bBa6x,5,NyUK5օY#7`salͦ4CA(%&jS5EpdG4#%ʹYkA+(m,M$ˁC?PNpy+@ZM,9T0f@wFǅ ",
	["Portals are NOT Garbage Bins!"] = "0F#j0JA,f\rr7Sh;L&Ȁu9D!t\r3 @I&`eF3)\"oM8$agjҥ9NX*rR'X\"h2es)o7Hp&sI@9Ne+?3Pk	*_ImgIE\000o:dX;lmbͧxIN^$Z&H!Rۢ㡦)C 1ێbh+-hfi@)wLԬAP@sZaaEssQaJQRQcG5!VEITR$yc^`[irBe.KUW]Epe[җO% QPE!vNXtX5K[tSeX lI^fxIty!gyRvj<U\\cK3VREa 8SETE1SPZMe\"AbցX}XQ#VtYh4UcĐ Z4VofJE	K<L]0QFUpLB\000R\n9hrPqBMTv-Ts{P5){m`xTe1BVdcuS[1^Xe<Hu	PmǴkP# uR͸Q	mn.6bxScZ NZ`mEADQdU3҅F`aԭLAYjwYƺ05QlK&Qj`Jc[ĝ=}$ɓ]-UMlV,@3HOww~i*aG(1pl",
	["War of the Three Hammers"] = "0F#b8\"L%$T4DC@k4Cy 9Nɔ 1\r8e!;<L'#@b:\"q\\l2&ix ;ӢFө(F$hqFw4\r	dB#&\no6-to7qca3&#y$gMsy5&y@AK	Ѯ}9'YLwbc/]-X\\oH7d2\rsN 2LjǛ1H&\\[MCv#w%	>eS	]6VL;KuPGzC7CDQjV՛EGU!5H0g}&QMeeh{4P]JIݑ7l׆guDzJnNҰ5%Y\\E5ScVV}\\`T]oH6\n\"&ŷF$mF\\ruq;`D2Q(\\ PQde.eQ!PZUwzQͨO	ɛV(%UIXdI;U\nDD' E%dYqaje(zѼd{XhLL9^%TUuT|Zm7}uRi!fjI[Ƅ~jdX4Mot,UxB_6mX͜gpfT^CT1{?ZqXMt%5K*M^BǡSee!JS4fp{(Wc?D{vhOGRT5O*˒IU*X6bp'xD^_dQ\"ޯ]!ttVŻx\000lzA01D\"u;ɔMˍTcZU\r\\&aiK6޴N`	!c5ooh@yrvNsH46*ڛb#:EnpȓQB䨹>V\"O=8T	~2ZEs.ܼ\000ʊ `AtrW; >C8Ab|*|<\"NZA#%(1~`8A@̆b[2\",ȹc9\r&V\rxQ5g02V*;Ʌey{f6,t*,O3\"sU׉|3j_2'-7G#	NȳDoE0lSJK#$J#\rP)vkgNCYbM˶J*B|z_p˩vy93\\(:d B)f!E'\000c`an9mϱ[E)G\"4R\"	1#	s`bV\"\r4$q5L3h H$5H\")VB⣼72\000천̡fr\n$2D1bLϬMu2:Oܬ辌{]\rH*FR\"\"%9z	bCD\nա(xJI[qAcT¶e<UBc^%Ik7\000K?zXs)Nt I]`H7a$	dt{HDG\\>ȊQD$jکAF5	NK*B_y;\000iԖ yrRvEJciRA}$$vf2Y2c)0vNzsM9zCf')iet&EA!T/L_1I$2{Mp<d/`JA\"Zªqs-8Gb\rBM?!*	'=CdWOz%7s!o!9Pka \\ZF4'_q`Zu=0n0([/ʲSIRi:2c&C/\\9!kqD=<izFO6]:*TAb_NX!C`\"N<'w1f/i_4m	:u.Ѥ>#\"\"M/	2qu\r/\rT%UTFuc91jBkXe.O>wD~Xe24.3UO	9ڪ2D2RDhPQz#&4_O>Q#=!LtnFXJ%J S.MqRkytUqH!qR^-!KBCP,#20	.yp=;8][Kk06R~\n>%+2D'Jɏi\n:EUlF\0005%u=Oyf]$9~gȲI(&^xNW%'SFJqgi&4>.eG,@ wJTF DzH<yB\n@P2S=\"\"$+r9_5:((IMkm4\"}FC5T}hG	.\"P-0Z%R.7o%lԃ$:vי`4_|sH5\".G/4'IyCJ\nHJ(8pws4+'WZ@bpa/G\\+Al.0zr%tc?hMt0+I]c!B5gmL$ACvuAuA^@4[VG}~jjh1>bτ%{pu'gq*WD!AF~%P ĉ>o:H~D_FOʇUBa]cb:QK\\s5Qsl`)7sl!e8[\\If\nD	\n@F3RjōafKc$%L!uBB#@A3eTW<Inplh\"U]satl^ugWZ`n!bbavȶq;цE)bT?cE\000<#?r] NWu@n@\"gfK\"!!Hܓvmؤ9Awb!tFC\"$WIQoG' 1!-]NQ3Sux! -d!kPy\000]6#K<A5qw*D7bJX'5釘mOd)v!$њ{y^ƛ{25V5-^h)EyGH8.H0!IwlUyt3𛕎PyW#j!2\"1tčې)W ҫ\">_f,!,RTWUrAa7\"|Q]#^ge@%>;;.CrGkXdTBj]4ǃS?]HNTI>k'鄶Z!h1-9,qN9qLQdKNSr1ra6e']",
	["Exile of the High Elves"] = "0F#q\000)B $Ln2aDe6	̑c)4a9'r0%Am2hnLYIPtSdv2S	y̧JɢH :\r	<G2	i8RCT &EM\\ ka1:7GSM4Ae4gzis<HڬOn)eč@'5F3))7}AJ9KM'\nobZv4740ՖrM)h١k#fS Q\rd)Զ9WqzcؑuW6%dBmdbFE;F(aX1.b 1CkDDT]!=d&_A;	'/sSH)Xo֑jctmBDnV!SuDuSZtiK5^kVGi]0xu˞څj!XՁbYi(_-MV4>'YSet\\GzeN)XT>xܚ\">e Ws$~3q֕BF%DlRءy8Ԕ9'v9]gmU\ne4wvFme p̤F\\g 9)-VIJTa'!T[eK|\"DEdabx&XgfxICe.4ƅI|	^q4lFiN;bf`n67ؖslѬLhew	v_kAJ1G!93eY$aqQA\"`SK%YOLF7IdgjltG1UhmےyP`fHwa֓NN8ڬ lnE%dnَo+I\\QZs~kQLWoyfKB\reb՝ZFY,N7\\ar옌pa0nC3\\=B*9 G\rSO0B@ceqO)h2$&0\"0xT#(Θ#cP(*DXt\n$LߑF-x4$D;1agd!&bTsbP|z/:O5|m=k\"T_6'%IF!1bPڎ\rJ@cb9$jMKa182hO/V4#ay>aΤ-Q}EdJJj\r[2`5厩)j{:-Ư0B%R\000",
	["Airbase in a Box Brochure"] = "0F#bBJA,A)$8@A$D[E\"y`@I)	򠀪N\"JQrqd@CʤҙPN!e%BxELJydDq4/D).0g9NSef9,ɼr.3AeCF\000j2S%l3Nr1_IZaAP)7k$ 07g:m8.3onSwW~Dp4{>ݍ1;=8D )͇p6ːa7{Ӡ@sqaPPhrsmFsaibFDXrtu}Gwh!߁1$E2]GXs._HFQQHa AyX\n@",
	["The Alliance of Lordaeron"] = "0F#b4!JAHT4D3t2Ac͆q@wĎ'SIl<FN	$p#1擡nΦ9G)!0N1p!43HTQb\n,H\rHi=I7̂ș2h5a5NIilhlHgJ.d30yyH 	$o3apa݄1j=ML;pMI 1K4tہ8m9ji+U\\;LX  іkTsQakz'uv`h5X1s\\$fL\000rUTx.)Ya	4yAIAFӅ M4yQw8eGmZ6UjQ1{RnF4amtuѤr\\aD\"]U]nbFcdiGwQVIf(bLhaeNrQf=KHN)sF^`ew mƉr1b04) ɄYUYq|: tly&PUQj`*rcd|e]QupD`F~4Ea!.fGE1{w7UAmPeuJiDJsFvȠpfi^˄EHalEF31gU`X6(fe%ͳ؇VFIvURAф#a\",iNB.:KDQU,\rd~r\rBT&W a6ї%i4y3-C4?sX_iv&UBDFzSoiNDrF-$l,Udz	DO]y9\\6Zcncn[FtϭYF+2)5k﫟*_]{ܙ妎<2*ReU;I#uNI9bK^7!]:\\<F\nAbX1H!u~Md&ppڈw'nHWB\"OAMˣ7x\"HIY-%TrPeTPmD$H.a0`F	M\n*3xH+0$ ):LR g*`L6ȡg'\nvњFL w\"% 7lXiS%aBn#jGh=	(9M_1r@ĩu;0JRe	rPF)L>R3)Ҁ0d>pJX/'!I6IBstqch	d]1p3kHb*$! Udpl\000pr\ndiBN`e\"Hʺ3]UBn<R(6\r`TJ=ZH݊{^h<I\\5PGa2041Yϣh-g/b}fzI\\p)y(2-2r22	(	\n樞&5*Z}`V@f)g'Z\"t>لشPPr'I}UBPO:M4e93,RI5T)8uW]t^\n4O\rIG!ÒD<\"2iv`&v˛x+ubkP{}uQ\ny;TU\"w{+S+oVĖd[hDz*`\000M0D`4RLu7\"5$׵oT.H\"h|iIFO=(71<OhQ,s&(.$ci'S-2L$96d*lt9T2d7ˤ40,5%2ZeMoPxKM\"\000eULOṊh1T\r #ZBPЭM6DsdM&U]0d[GzĺpMIJhP-\"X:y~eÛ`너;qCKxɧ6ԆiԃqEQ̥5`V\n<Fn<;3/r8Ǻ\")< oAD9aPe		E*Ɋ㎭f>ƿiЃD.ksF4?#I6j?	WS\nBuxr;4tZ 5tOGAd77Wޑ<*=vUbn)Hkȣ2x .sT'ҹI39d6Xh\n\"{)Nmf(HurGn_!<$u/O&Ή*ýaq&r\\U-& 2	]+)xJP$=11RBx4v1*Q1QP	c,v^՟Jb1wR@U-g4A2hS$*DCaaRA6s6daK%įe<-Ɔ;t8fY!\"ӒLORV5'фRL+tAE\000AB6\"\000\"F CㆱS]6\"3d2'PèZ[#A&D@iMuD@@KPdm[8miԒf_u=hATSRd288IdcuJs)v&m9XNgvyAV|\">)&Zpr_\"?%LEEPy0X}2^|!qG3hѵ2PDh+5\000n% N`SpCaUب15rll3u*(W1Q|\">+|oze!E4LmaQEkqfv&H15E\"xtuB1/{Az1wjQpd	\0001<[R`3={0t(ѹ)+:i?aA{USTK(AsAW(a7xt#a*drgfu`)Vjq]\n@",
	["In Time, the Arcane Corrupts All!"] = "0F#d0\"JA,a9 TPa3LbI@n7sADy7DS@b2Mg4I<d0SxO9hhFY1\"y4!u\r&rMJ!YO-\n ;ChLr,i6`8zm3)MӝT9L~<o3	k|N9r<lOԜtqf:fYE03rE\"nrGo~ *Z/HGAmp DQB,<\nQ1TtWTLeN%Xi ȹloUu.nF^U``+gRSs\\1cv`9GBoen`",
	["Damaged Apprentice Journal"] = "0F#b6L% q\rQu9& :l<ie2H$g#,He<< 8&㠸}F¼Pa;E&3` S1r:G\"d2 6\\ ʣS\\ +b\n||e23a*:,vfE-CI?O;P|\r`l4#wE%^1&43r-6wVD;1w)NdsEe/<{qQw$5~q:rSSf:wy¹Jzf&hm\\$4llPk`!Q)T7]V?JѹW@!\r\r8|liZ8-jBTE\rNWhfN%pIceh@foTauekՄaHͨ\\bqKFQZTsYQ^V-}mJTfzaP'TUuƅb}^Ff:FoOZWmGot6\neG0y8B'z-ja	Fg,eoGX*8i)nE'DQ&zNI A_p)EVu!JҔb)#V4i4\nE$4C 5cb;gF&+!Hz|yUKO¤QoKZL8+qXHfR{Bq7SD)tQ*zƔ%+BUR7i%]wƙeK zh}lY\\Ygj+łOeX&E7A_]^9@ziV_B`**qg^WS]h:$3C):xք)!:A{H>LLje)U%uYb[Z9O1ӦS`$ipZ\000g(KH@C:E}@NC ?X b+b(ʐ\r썂bUۢnzSRzQS1*ܑk48t	#F4#\\4>\rȫ+\0000C1G,IQ4\"Uu\rAFe)Q&&浛yB`*QP!HN)@g𬔂.DAӸM).\r{(rfI΀9HJKq䋟xd\"[Q'FJ wYi4c*ib'\"EhViC\000<bJJ4fe&8T rP|3&@I_m@OH22 DF78ż,$_Z8	Y*G+USLf	dr] 浃*3k9EP)OmȞ_\\R\r!rqV^ڣ\r\\ɂh%EՄjIZKp=,Mya\000ڹN8$YIQ\n~Je9oSQ$jz\\i:\rP9 @+Q1/m\000qNS䈔+*X3EHHk$OUBZ\".2+͢/PK%'7*K3d	LT(bc%	r*)9\\CUj#[$p\000dt吨	n/ocWCmղM`\000ʣlB//#y`i0TAj,Y[זJ2Fxg@mq@nKnh0@O\nnz+2G\rCDC,e<6\\(Cxg*r;\n7ftUWͰKV'H{B\rA?L2(ʾ\nom<Jj'':{gY1*v7L,j</KӲc1.'آ)HeF`#n6Z0i#ŧ6e W6{d*h(t\na<O	$::R]\000M%%<x7PȲI4!@xD!ǂlD4KxXh8Ě8 OeHĸ9Cy1v02ʩTO(Y38+9E8`Ma:C)Ɖ7'\r6h:~S0xWH<Pm\rkr?^l49[4/(,.ʹToQ´V{ϙ4pAٍZ7.P\r4͜Egsw1^l]oŀz9٥\r2cD1!\000]}:ߛ岯\rE*5-S'}0LuL0-t3/\r}gmE$ sUx~PJEn;ȴkf0ʌ_UHJa1q^!HTw/XXquzzSTkCZ%`gL\n@6y#!?s@6DPHE(8\"WDM'[a;UDc)xWy]PeRVf>TO,rQW4/Q{f2Psu¾uraG%qoX)0SѠ,Wu>W[Ar'6sf9wi9&3DoxtzgR{bQaDa-6Oh11@(^ד@R|C\rO}saTuJ!g7ua^s:BQ$)%eMrb[\"}qUZ\"is!A6MxccsZ3э ѕ%##1-W0J_vP(`-2MތkISC]Q?`T!SA}iIT-$ xg4 3+5P\000u9li?cl7'1EB{~8U5<ҕ2F;ъBB>Qcv|]ػ;vQ1#\"\n@D-Aw7 0MX>+Cg-[!<*cyZS)#/v<=^Xh)e!WXCC??[qi0vTzug.pxŊLId^!\"'[Te!ԣH1$9Kԓ)Izf G:,@'+^0OnD0}V'aF",
	["Kil'jaeden and the Shadow Pact"] = "0F#ȄA JA,i6	F)nfS)n3h:EIVo6\"4fg#396\"9\"d0cy2:ND3Ao;tq!0ƌ3i،gImNku:1)2Lpէnff'#ak\\MmCPo9qA:t󼩈gȤsIcqN{stfomAR}{>U3U\"|og6x#lM'-fF3	2Ku16[nKEeL(yF\\avG,lBAbU(sTTfJEfLeSdscGxp GebZ.Bа\\]c`6WuE\"-oEV5BLmipVaFj!n9GҴ#HN1'GSUb_IZ] deXtiU\\\\sag6EQ5VF&u̖*$Kf\"%\"MA+ImyUeGT9aW\rбrajT296	ǡF	sԑEERnNS%17RFb`FLahMB\"fI1+_jEFX}9PTH R{N(J\000 +DWb_*H+E%YRN9#m7FQcUR֯u)MEA)d,BoHp|qtgn;edadT_73MI/Wi9RQLpjvvșTG\000p\rmWG XgT1sjv![}bYYޯTe#En¦\ru5k^4jn߀Z')dH-4C#wZbt}Hx0|]j	p^:pģ$*c\"TD%\nX'G`I	`qPT1O!:yLŜ3:8-D:C3x\r<`pt4AUv3rf	'ʂ#	4Ҍb-צ_lOX J\000/%h\nfzM̡ckk\r}SA X	v菇9iuCal,P4Xڃc'OF.H;/!3e$jp`3%P{&Aӡ#aJ !V5@r`#IltKL\r&rM@fBIl1EKJ4^mT)4\rM#n:Ơ`P}(g' ,7ĎSw=*#e̙\rDeI˽7ƙg(i#4tKyGAƪ0{=LI8z}dϖPVk'#?H]tI>GY!vՍ˕.E3#q5Dod/漛&=f$BtiUDpU}HԲgC:#-PY)z+;$e)npHuPH͝2m6bLi]kIi1$Kr]@d\r(\r,*ZChZhMh#3ZX U+g-c+驶mҧH*JDJ; ٠eJMm\"2e5Gv7cٰ\000",
	["The Mogu and the Trogg"] = "0F#Ȃ4hQ\\t4\"9n!i6E(r:M:䆉1g:\"L ;'Aa7	e&ha9F41@Rc-`\\\"BJ NIxoIE`9A;oBAt7fSIHu7Bw#rhmM}4oU2LSu8Q*M|9ҳV;}r̮h[5]D 3ex\"oP&}śx#JŊA%ci@]:A.gHոrK$LhQ`mR(\n6M^qFqHH&AԶ0yUsG!S (\"TQ.Fu]GeR\"eGVo4!\"\\]JRAi)D)I,kDTEDHtXQmFZi]\\axo!DWu:yDyI'f.MuO]Q^F6f]Fa1XsMtKFag*J&i)vYYgij?[Hkdq\nvYOw}\000F.HTeOסa!LMRAg[ZPeeZukZ;uF7Ēe	 sbYeBqIlB4)F4o%IHz!mJji1LFyGq]rGA!L<fӹh]U8dѶ|xnDnjߦoDf\"!0MmJS;k=RD\"5t,jE&1Ͷ[[V!tZ}th5ftk$(\"%qUQm̈>*#Z:-3vJqHcA0Wۡn2B&plZ@8\r#9\\4;7j^)|3Vj,[yRM7'@k\r2.4b!2\"f$0lO+&А1t	0dq+Bm#DtSިBpO&,3dubu9Hʻ{O'}[0Eg@Z$tP#Ǜһ>KDHD#s핕>e;n'щ8%D#J/yhvRe888	d*KąDyuա~\\i1,I>97ꐢu^ګ{O5TЏ3r2H<!dQD$<0@$QFξ@I1g4	c22\"2\000xpZf8!	ZKN1/b\"㈍F(VxiMS@N`dB9uPEpv$1RKiYi5z9\n",
	["The Founding of the Order of the Cloud Serpent"] = "0F#Ȃ8#JA,i0@L7S@h̧1r7DCA 2O\"1w0\\@syc0cb74|BeVsCP,+=QʝV !\rXNCsKe2JѠ{s3G#,RZ\rM6иXAZ\rѩlh\"\nsYO2;lSVo7\\6i&CLJ(tnU-EIz׳~sgaksJsF.QKjG1|oڵli.r\\ps`ZYdfarLٕm@J_GiG5[$tYtaqL,^iꃇT,aѡEwb1XF51qr\\PoVu~Wڶwn-O G	qo홙5PHQ)T-vefI^f<rO7GՄukއ6+~fOOTgGaemA		ױ	r:uftj4mtZjq,of䴁ulesYn \n0IrOѤqH :%5Fq/7hE$)>UduQAcXfGact\"H8efgFVBJݷ[x{&)R?] pO44cOU!?OlaR!&E.v))ҌacqUZn׻`jp(!xmv(Q108[ӌMO<)/6	CNr@gYYpOz!yQѩ3~rR5Eа秾Gd(6f,::NF1aGصS.Xsm&JB1'n\"sl&Жā9񧔂nyaʶOx')PUVr	'-\",96IOS 5l2f~=hpY6nu<1Tm7lO!60\000G#1`(UhFoU\nQ#Mo\" >Ʀ!B2PegO$&E 2!gq&|1>>(<J[a%@ %͢U#I_6e%YJ6\"00rxT\n\rLyBe2jcCQ9\"}Kix&W6%$`Јz~=WdI&+Li\naFmJb\n<0A5cJ	Qo({FW!W<,r.-Xae5ƚ#+\"7UB:HSG3b=E2p1!aE$ԠW'%5?(z!Y錷Z\000EXJD݀r*AÚbD804Lvfr*u'&֘yFI?GAF	/>}'uO1<9L3Rkt%	h:,g?*siY8d&;Tk-Nglj)MRpL\\dP\"ċY",
	["Sunwell - The Fall of Quel'Thalas"] = "0F#j2HQ :I&A9DL'1d\r1	7!a#q@s7b'y)X 7΂|@l4&8l\r.l \n'Zxh0#b~&g6FpoXITF'\"3)ñ?;Ȍwo7֡i]= <W9AШPU6\"<?F3,r3u0*UJ\\piny<Ln;͖Bu\nCzRnsQ<YW1C2C᡾Ll T%87mQƖ\rdRUx4 VRxdr`bTo 6 GbU51`7!eKrYB2B\\$pSӖRdWV\r\\i[@oxs	rFщHSєfydǕu,drOܱInG GyƕcTpNpGB	yHG1i^_计q}yUS$kw-x^%IDbkG:xgaY2r(앒KG$,h!UR\n.+C n!?;kSsGt^AIӘ`~c'%qW,ɣ)\nWwoDH+wMQ7]5wiQhg+i!]|+~o]8EfE\r	+keM,+5%Wb'<		uK$V *7GyRRԅlM5Sku635VE{I˜iIrY*ide{q.Q\\ŖB",
	["Wrath of Soulflayer"] = "0F#p9#JA,h2FS@o3r:'3A4r4M'!p0'Hy9&ib 3bi6K'\"A 6hΰa7(&tHd9Lu6gaEFyc0+95̵3UAEl0Mɔw,4tgiXu74lyjΦsE@f,'J\\v2ѣ#.M	s7b7>Gja;\\&]La*DQYVFU( B~hUD\000U1nW ]oVB-\rPYRUA|RPtiDeAՁq(wuQ9T[Qip	bvUrS݈eQUI>x%eqF֡]j[5tYfKq|-0xDFLUHxu8twD6q#j֓eI]Mֵ	Fkؼ\rqEcIRZWJDʹ}PV	DT]G%#IRt+YY[XI⫥FAdTUwG le>hG{iT`Q	-.ZHڤwgѾފs^Tv6,\\Qcs#tyE99M1nRVf܇o`$Db_m3EqoE\\ sF4ff	X U@yZJzddgfuM_us:sy`RueʦGg	^B\\sݨ}Z~Ie)u\nKNNTU~nKjr]aY%\\qw[c,X?CEy_!?Pa#.)N\000`<|\nyY/-FνC.d̻ NVړ;9rE)0c3ޫJ?kH4IH}&Q\"vt&`LLe©RhS`8iD42ݙAfKxڛrtlJɼ7+\"zmq(9#hi#fůcp);6Z%ȼ|Kك2Tn@oXA+R6~[j<Pd*4^,̓E%\r\\ڔt\"\r!2dtsPF!E؆vN46 ]=OQӾY]VA6;$	3;E%)'D3p\"\r%]SIpt/!\000TdSzӘ⠸(<3N^yL許FMJİm_t5	U\rOT=F_",
	["The Seven Kingdoms"] = "0F#Ȇ3JA,h2Sa9&@s:Mf:\r&Lr7DC)42m0tuNN\nle7Jb8:NB	.1cx<6s-n1Z+FQ`ue3Cp2esd6wYl3ieCS9@e0k}sy2FXja6N\"`uPU\\ӥ:_u֮A9d9r)34fS?FdcڍVG',aQӉ,1'fssr}ۄE++}OgV=M`\000tFD'GgKa FfuP#%yu']Pґe-\r14rUUvt&JfhP68dU5OTY}Md:OG5, $E=1Z5EAKuMEVU~4T&(]#}i6sZE5J1tIY(y,bɚ^Z>i[ݣemFIfQ%!IښIkEvKwJEwugJژlf&pu}Wr	\rEiJ.gژe&62NGn\\Ae21 R7ĚsDVjgve`{guDJf5\"Jb=sE֚۱3Rl^4cRk]XԷW`0K/K\"/nF8&VpE[_CHՁSʡV؆Ȫg W,5BinuR$ˣr4z]_m4vlpm$hZ%j<FMWkz5/luFUjf8J\r LI:T~2Tߗ妍r(ΘuX9XjHT\"(޳pȉ)2WCJ\r<Ek\r-t:P[qh{&\nB\rs6ɰ`Z,3-ԀXHp7N_*QÖdwOO38m@ Dhgz4Z\000O0?IH66cCit\\RR]r5EPK2D|o*vOfYȪpIb#PW Ft]c^ᰰi)0bw˳:el3>xH%L81?J0+2ypl,HydAASJȚe8ATw\\t!A#ɂS+DE@	\"\nU=$̢\nQg#4&kKxY&Q9#ЎrJ^Ngr]99T\\g\nVA	?3lF)n#\\O,hvPȶ&Ey\r6H%N/IXKxNQs$hA#CHXUI带\"htIH\"]#A3)\"D/%NW*J*P+I6Rt\000	X$Ga<P! YK\"Z1[1X}ENu.eINWBwA,z_ڸb	VԜky'T@X9&aqI(s#IbL\"jf#dBy$aϺ\nmFŖڋ\rUNHjn^S\"Z?)vͱigrcTUs-,0C:[kakQ35ʔ",
	["Polymorphic Rules & Regulations"] = "0F#ȂC\"JA,u6D1@D7\ro6M 4&ItF)sH+LFSav\r\"Y)$52Nғ=X9M0i9#tu1\"\n\\uf	dRJ=p6M&$b9J)@H4OW͆mTh0-$1mB\"iAM7̆hS$3,X'2Sqo&cؤeԛRmsnEـ'G(Pr`	8e UvS9Qa0BаD 5EiG%\\gnXT]fJvh \\.NyQFĎeoƗh..ёoRNkWiRA$B4e!սEpZɽaQ~*)XaDHvH$IWKI)qKk\"4I݁Ҟ]ѦYYLoak5B_R99vUUcQ/_ddqQHMFqQ&ZfZ08\rf5\r16^(o$Dua0iQF`&SF1,|-ZVDXpCvRNƔt~aB\r(h3E6e¤QP55P\\DDw\\I1HEP.F-qqQ)z1FPsUj)yG%]]בJRYۚQ՚GFhս\\1qb^$cXF-UG\n\000nZSIcXp\\[eU6UzceGyZ׼-QnTmIVGt di!&GqaE8a̉]+JFa#B+4u8L+`=lei^6)j`\np-+LB*\"`ȋ(b$^!E`kD1^1SpȌRv1V\r55σJH(pMOq\\!0k:FrZah9\"Lxf@i.ުMaM)9ͦ2da>W˅#@UE*ȤaP;K+'qOXMUU)sh3QU)/^W#u8`&'FLlXsEM6m)+pZ-\\*)T	zAA-)=ZE,&QFȠT[rdXVEĵŐUWG@dʁ  d]J$cޓs\r	v3kDY*3&5CAY1,.Z(_G\rۙyI\n'g^rD~'-\"rt`+B\nr~y$*yAS(RJ-)8K!%&g ve.E=ˀJC$\"Ae@2dZkV'2]Ga\\Jrk\0002\"Ի!6a	AN0Gz9.\njC$\\j*E*h[Ętb%5o.O}1\\ʠܞ1)GܼDb)hDa Rb͒iϘgi)i24AUvEM\"69#ќ*^ VcqI)T7z{\rTAJ|EGX>e9CY!U3PP)sJIgVi!PN6Ƕ^\nZ	:6|tV\nsCmϡTDDHeX]#q9\nOK\000(H",
	["Legacy of the Masters (Part 1)"] = "0F#b3L% R4g3ɸ@w0w2Sd\\r6fdldIo1LFȀe3L'A,n9N=4M3).C	i7)v2\ra?& a;*1AM7u6RGSdF5&xәodc(\\\n(D DjIc:QΓٞe2VD:l0n3<^\"hsb1lƤ',|[NV!niI]zGYtCM5Nxe(uQawoXp\"j!4edzQTu%Lw=s\000 o` q=Bq mKCd0T_QԨkFacwm\\S#~%-#IFv$eiHR2EupЊH8JaZG	x^Z&R֕$sI%ltQpp	a;ض5EFsKFѽG$Y E10Sde\\d\000E]DwezZWu扊^dDX*դhF٬G&A>Qm;Y1Liv:PⰈAKu1D$GeJWOFliu'+6բ^%c;IٷgpbF2É)%Gؑr~d~D=&[2nR`$j̛Gq}]E|lrnۜo^5L]V&N_c1Sst1ru*qhUeslc\"v\\gx*>W4B5Cj5j8uinvG8&RrLo>te S8fI\rq4akX_J	H&uU'[U9%`e(Br)Peey[1Q 8vwDVyJFdFKoO;\000-`qKUtKN#V`\"fq}ՄRy'FLqJVIM[ 8c\n0}qS%DwI6<2Sy8A87]{*j%إ(s~_#CY$BlT$i4JXBMu%ljhBebIMD$$gr>2	9<%LIMZ*PVmvsXKAho墤@g\rn	cQU=B\niiQ(?#{'D)`4!hIЛb;Aejͪp3FYjoɷOVa/,0R;tD=sBԃz~oIs)?!ꘗv%|'CZ|}bpd1)H !RNؿ E_H(aBv3?V?j!ހȱd1\nW N!ËTJj(e%_2\nj(ˆa\"\rtD2c?_05RI<ݳt^i|U:JU9\rЄ8|O:vfvpq7oۂU$5k\000-X8n0lH%9ȍf4eSSN9XIfZaZk$&=.CD3QӝrC8dYwB[/Nb\\i%=vŮm<'\\_uDzFG(lD3,@:|-gܘԱ.)#3\re.;*FG;\"48Atla1EԫY-dU25\000-0d\nyie-'$|JV=8S_N 5o=T9^>g\"kpI9\">nHJJ[9M#8ie'5щX-RaUM+{trQJvɹ;}J)\"b6[1;Ҁp\\B)i[$:MȮMkIO'V>&DO6~f>Fi6s_Dބ9UYV#y.-1m$s΀CVT9S4gB.ޛxh94bLss.* ,^8-haD$\\TrBZ{\r68,Xa2D䁑/>_E_#-Q	ClF\\wr2@fN,rJQD}ۃCa~+@}L*$#}:[DZ\"\n:B'fZnIe\r'j@?po9r4C e$NHLＴ\"Vm<pdn-WFq	X+d<.a	~r\\FgaVJƢg;I#X`.pM?'30YOo#RQW+sD&щ.cs5NQ37(}a7@L{Ҹd5PN$k \"A%3Ps(hT&,ĵEK%AL|0*=Q!D_O5Aw/Vwrs.%6)QifU\\ 0_s\\%A3XJKw-;wqqX|1 7ǷPLR2BA2*6Av)ׅ.= q#IVDA04P>(r8^Ф&:_Rp\"tKB' r	 iw2ABxmd),ZEo#3o8&7UG3A1%#GLf\000Ayq,NUW:!->43;h,+NoaM70ӈR'Xth4Ҏ.	}WW)G4=na($`usnƍ #`bmx.r3%0~[U([{/",
	["Rise of the Horde"] = "0F#rA!JA,i6	F)nSh0#ƃ(o9Es	@f4&a@p9Nɐ\\ *I@d3yK#t &LyO.3d&Se0+u7UMx 9'A]7͑S<i/ҳ\" 6NS@a7R\ns)[b9iPةt4i6SXOל\neL%72B9iD)4tj 2fL\\i\r'l}܉7J'ws2wduS{d.dS&Hvl	Dv]gGlWb^\rXGqᕃR\r'JFU}7`YF]dhLtDYBF}uHF	tt(*1HSujXlj`41F>6eb`ze4(q(W\"lGY}6Buesi'Nc_FQtcfiQ\"3mԁ<rXZDԀmS)\000RĔf3fedF8 q!pe{pʬ61#bѴvcS\nƷPEterPrwdakԆbvj뺨K*IF.*܋mpUfcaoFIuR[C%{&ځyDliJD,5B5vkS['GW6FHex	p`ѡ\\')PщY+4oRA9ijI>PGq!)!tʩ:RLnVg6hL9nb4BՆbM|JhpKQcN!ScQN{h7cKΔkTF=YVְEV{aQaviI7\"D\\2lŀR$%q`kkNH9\rą2D\"a&p!tdRf]Ybl14FȫA̝0b	$@HLày'%p<+:aL@֋c\"\rdw\\ICnMPQ9(m*Gʛ$v.C	'u<e\n#X)P8Q47¥_hq(J1H2*ħe127mÈ`12=p3,8C0	b&F9ЬLq\\Z QQLb))%\\72Z\rYhlI-.Ka]3vȵdwE4+~U:a\\!B:]Д9eHc@r<$\000SIyT[[q.)Gi6X;J\\:gz	orKѳzI\r[`љvk̼ 3ܒ8]ǝeRwfK)F>bB	1픗.Η,#\"}*=TJiVi&X*.ȟ\\~ ",
	["Old Ri and the Million Souls"] = "0F#Ȅ2#JA,l2\nFp8b&I@h0#	 7(t@e<ctFhs;Bhg@r:LF,A3SitECE4o:i&2#Iw=kaTl<Χ32?hLl7Se2#5dI$M_'BNfl`ifQt.44i3jVNtA1X|o(	lNoNpDA\r{MtĜ+pEױs>!׾J4pUyRtOnB adqgJY6 noxyXIP^ǙMxF,xjה.t4mѧDEHtn&=G!oE1dѹQfPyfՐ(ZGF:M&Ay\\Fy9nau|\\`YJJ5p}TGtHSF(mDYiytETe2IO(F@wGh|QTQW\\Aaؗt\"D}^\"VBvgt g,W߸,dMVĊ&1e(@X)6BQǅsL*ƝjP`_y)ϲY7NU+:_,upe͵jPOѭq qI@iv!G]~F,r wD᧘&kXqAGAG!8VFb)	a4DsfdSdQMi8uHFQhp%cXtiDnSوqMS^\r1ytmҽNQw@cdRw=sX^X6GV&`UP1cx։݁\\wMXyCe֒ik5HeWXe.T?+k.n\\5/A[R0,$ɼC~du'B\npCr߬8Ko, P	Y3rGIK6%$Lhbl@+JYyBw͖YD&aYV5\"	rTꆓa\"y_thA\000N\\\n^$ּ`uE6_a1JX4dbFTjLkT4u_f,x8p?:OfFK|3[ɝo%\\&fiplT^,BjYޜ\r.a/d&+OA\rEH5\000L\"c\rT.PURn>I dlH:TCK\\,r$E{ʙYY%dyMJ+MHSFs/ظH	3,T@ēt\\ ,J|%\rNdOdH7S_m4k4[5HJl4.6Ua2aŚrf\r2L;\nmlys輅DE\ru8E\nQl),ً)'\"fl\000v~]>`B%N)Wݑ̕B\000\r 7H1\000wlp&F_[+AARifA?Y8MN1PQ)RhI\"dѿ%pҥ++3_SPAS5D`qy%S\n\\%k10ɐJz\n!o6\000@M MA!O=YQ%tؚIb=up7QE9L/!R\"#$ɓ{d`e!kĹ\r0B",
	["The Fluffy Bunny"] = "0F#dDJA,h2\r 7HtGB!':Q1e7b94b}?APX\"#c16affsy!\nhx1&i<ZmVeDR\rdtDa<&I#ISb1\r&<`7DN3Ng;nN1rR9Ru8F@aΑmޤayvjcy|w`3뱎K%%t11%xtP\nA,ie<ݢ{ͣ4g#?3B ]GXf!~\rG$=R!IOTBQVV)Q`5K=mаs4EImdD]~R<n}Sם|SB1C!N9kP%8JGtH(oF!zR`FP DSiҥTkco5M'fQqiA;L}DF|G/F%8sDs;",
	["Secret Lab Tourism Brochure"] = "0F#f6JA,h<'#(4b<tL&)@uMC)i3eqA!0&I-3'	1 ;͑Ve3LsTo6\"9LΦ#I@o:qZ093dDx8OfVcHYhe3LoNX)7$asɌ\"\r\000w0l43	;g\r' :FDɖAFtGI8WUҬբ@t7w1ph9i8bj8BP(\n7QIl Nc1_\\]\\{WVRM,fѝEhgFdqdF$rB t-PE]ݷt а GBtm2ATTR0oG\nTyZ$5Hqfte&&XWDFXe*ZLc&)%fkX:#ݏkcS&h6D	r}JMw&V7	pu$1jAoBFb(H1\"Kq@\\u嚩e)=TGI`ҹ6vbeGI&ĸefnirIہis۩}_)m{A",
	["The Emperor's Burden - Part 8"] = "0F#lE\"JA,e2Mqa:&dT3s) 1)e2\"Qp/9r3AeM&1h?\"1M@l0'soG\"QI!M5\"N57#Q|@uIky\\ $dU	('㡾='3R@s1Imʤ|٣O_,#(u>lJØNcRL\"&h/N27ct Բ{IKXȎFL\"uIi[Qӟיw%_Pgs}m6LS1jkSqam`AAGAFG<fx֝&]B$,LFvCRĉDFZQ^[6TI`wT RO4SMkInt oViÆi 	EG'=UQx0gٕ#!?wo}&	L`nѕ]M_5nu$gV!t[8DȦcĖ*%Y^2uHaAV<aj նhpZ8`[f]ƹcK-ޓJ1&2L C'yѨY6l(\n-y'n4dc[;]BekIIOuzuQp\\6\nm]]Ag@<>LiUaftd솝$]ddGQpjedrVT}ڈ-`\"\n@^ǚ\"xܙpq1UFvN=%^c#+$ee&Tх2f3iAdjemRҔ}TZFa5}֔8Yɲk%kkRq:!`E{ݙI;Ym6sQHF5|f\r22Sf sGDm<V9V%遯ڲ |Nv{ڷU>i-囵2\n/dʉL*Ov<ZYD7ht<$٭:ʸrBa4RO30@J)XiVѦx,a`GZ;A̟PM\r)B,iz4&\"b^۫@\n@",
	["The Worst Mage in Dalaran: A Children's Book"] = "0F#r7JA,h2\rƓ9 2ag2A`o7$18p7snˍ)e&3	+cy/ͦY|JaĨ#a8o9$3	c2Jssbf0M1\rHbLfD`l&Cyrt\"&;i2pfLyM'Cmڜ{(fGtqLl6Lr)ޣ6ִ;A|\r$ˡU˔(Hw_\rYzKk c y#$m]w[FbWyHa[_Qf҅Bd.\rGRrU)XZp^a%Jt]GTXa`iEhiFYdAiF:jQQ\"Wmu[Tr]v'q1XuhiFو`rw`8݂f)\rڟQqX&5Bw0嵽r$Dd~&[Tp[twlƇUS`DaMB!%y*!vvH[(t	Y!`A[IugFr$fiR\0004\nFEtn'ixwmVUN\n{'6uYlAuj\"Q^Y&Thefl*4BVhz]fks^sFҾ8uYFkWHDG9YVVx+,X\\wR%lm^a1ĜwHl4@rƀrEH,SəNEkLNYHt0yGA!54FPoWZ7ubNhW^S:VԺpwFs\\Qh8c7nQZ6ps-MuF;KQuFaaT$곀!甆бPe\\GÃXjz\"xs\ntJH:0@G-!ԕ%rxQA@DA>2mC1cXfqн ܘ*м\000g]OT9`F̳z!\"I\nˁ#$dNDa)3'&6Bt(%|eIVYD699Ne3LZCE␅$fP8pX3aP3ԨtHg=(X1V2cH[De oR\rcq(>ᵓ4r\"KUjF.\n,8_7;ҚIpi+i*ti1.L6	IÔ*!;ID5I윗Ii=0N:R:ERT?l	9=VKPA8o90dYȔBé'u3=6J9DmE&e-[K2II9e4$B\000}$قjCrQ6	=T^5:¸\"N@eA3U`:D8MVMO`eP	-CE&NTa7d8f9W.D-Q",
	["The War of the Ancients"] = "0F#b6GJAHM0Snqsc2CA#4Ds) 7Sn4\"(عN :LFaSMƹ 8':u@o9p5I$	Ȁh7lBg92piͧ5xQkJs	Drh#Fs;Ȏ2wJ(!N\" \"d'*wwfCy8 D1<#`<sLj9HfSq*uh1{BUo{u#P*|g0 YVTdPw`qo\r\nAeI0n1u(eu^e75F7vJMm\000doafSFqtO@h#;TnT_n%oƴ`qxO5nEb(GTT񱆖U&|K5w_]M!}XFnk, \\wtYXG-NN،1Ayh!t䙄c^G;*D,u?LB-]ASViIהAH]U	S-v%WQzFTfIQb ժFqyl:z>u۱I FdvH6NUԽC!eҡ\nҭgp\"Z\000sхi LpX2uiyu4d{JMB_E'Q1sKS()teSzH̨An(MytRIf|FnUOv-Hk029aTǲs)y`\000o`5<p$puo9nMG\nMdE}R`ot>(D?%2fJ:9W]t6NM\"e]4_XbSP46W;B,2e6)]&1vؕJ%@Ih?ޡRlU*(՛\000Dz%&X}%ư92rDJO%h4[%Hl1p <.%ȓS#Id HMIByAO4F\"ަJy.V>NWW=pKP#&@&i;[&ٲ4jAkp-s͙W{' Ď{gu,5ts^5`ؐz6gR\r[(SӁ}ebt	p-.$VՃX-Bje,$v#'HI\"܌㶤P[#dwxOMFᇛRr$G`̊Ad4'Ih.	KbxNTpyT>EUKI'	5,i*Ĥ6.|jȊ%{\nigћ窞ʘ#2|ZZ#¦ԛnf	;IƸ\0001W(EL?5i7*E I\rzBIIa2MT$H)\rål{&$<H3z5<dґTNYBZ[Ky\r3hq*c_bT5PƪVi{y djmJT*y*ĴF.9+Utpp )|>MVq }\\`c0JX,[I7gM+씞pWfz1K	d\nmtti(F2Edz+	 2R([E[ʪ1.\rRE{6@kEf&Q8E00t$L1JdSI84aWP\nxPJZ2>h {Ii-B7%`JpH{2wOc~>Κ0Ufozr$g(Y\"2`ĠGjM*ϊfhn(d/-I,g`F)$Vq}gMVѴ`\000\nKMg9DT|ml\r#c\rqJL}3Zyl,)5nmj{Cb-k0W7툝6B^Sj,-xxRr0w:V}CbNb|6H)%3f@Urk\\+R*T0NKPFl	tZ_α%TpJN5mb*x2\0009-XPg*pRC);E?af,|?!,	\"I0\rEyt>fQ6^=-RFcr'՘I5ӊOW\"?Tb|{0-\rlvݖ-ځ௨/xZ\r)45oTa'Ծr;Ӱ-C\"zAtq!aזp0S%AW+lrWNa\"-A*!XAB<$Rf9%/B a%V1.!.SVD7i\"3!NhFa>t+?a3%rgdVjbF1EE/OxkT7AQh?3k1w!F| 1%3lCYd|ciTHZ<@x\"!43vwUv;g+b\r}Pt!]҈RQ$uv5hHw[A3q93s ~R'\"FqUMd9\"Vh?s}a܁^Wzr\r[(@s,([~( f9\\xST6x'd+Fq}(6r)H&rL2hj*=h֭>&uXW?X6h 9S\000yT= rE=1&\"',\\~4Ew?FiQISD a<VQ'6\000rBQ)`ocxEZ¶A37h4@A7\rQCfOZZlv|#Ur\\pg*ӰI$fYUQ2M7XAp tbpD6yx6ԚHyy|hq'k6(f`-yP3%$Q\r}{w  	grr^xsIMxiY2",
	["On the Virtues of Magic"] = "0F#j7!JA,a;Di:Dtd +M&\"r<&S~,e7\r9 9M|l4R$oMQpPWqa7*b\nYi2DSn9)r2L2Q9惠S3Ţ)bp0Y%t4 VpY9mӘuRI&n<+g3E,q3g3,ܦI}[MƸ.g\ny@p4V2gd*\"5aE&|?<@hX&-7RaWMO^o\\F7X\\Ff\\s])GQǢ`Ɣݘ[gqs_eGKGh leKNVQq](rGAC!g{YLtUIvL*KkyY(IYGDe1E4J0D.aGHlSߕkaG)$,Nbe-rmӇaմgMttDVԥ>a$~btWl9WѥJFI	[HK%`HwW1ti$ptnKvY̻\\&!h/IW[!xV9~'~ZV>i{ qMFͺdTc!W_8F3Jp$Ȕ(u4N& Q]de,%X_Lc(NkOSB0\\ E )D,1B1\\]_gTGYQ-pqfhn4MvqP6WY$A'}M-6cZl\rߋUvXX7EIvhsuVDWvavG&c7\r\\tlZL! ۯwJ	lW:xB,",
	["Military Ranks of the Horde & Alliance"] = "0F#b1GL% <$	4<!ȅ\\1M9z\"1MC)D> 		8EI2PD_F\nBM#g#+2@P)MƲg2\r`5HdrY9f:dXxPI$#y嶋@M0*1BB7}FUU*r`Y,֋Vk\r.2,y/|b2=rJn/U*Ս%lkX{Oc_\000wkMS>_9w>rh=nVmB'}[{CdM\"|ۨ%N}Mi]vj}n`FyE` PaGa,YєmMQ$QCd=D_-J]DOa%7S%\000T3MSuH-'Z4PG&82rfyh]HvjƵljC\000&xxwbD1aGoW5'7v\"9\000\000mZ]衢侊1pget!gj!ݖ7 j\n[ -uK6uZj6b\"\nbeQ\"8#\rd8F*J>%)RVIdFЂ_MacaxRٮmcφmrް[*Ū>%dcΏ. $kkC;p0FѐxRy댆4z+&\\^\rK9+|~3v-v%*m%@ms4:sܝʞC\rvز!/m;U7n7$x4URK OD:OBTUճ?2[x[#Ҳ3Qcm<	ㇸ,717ܯF-g|:F|}c'+nsq}ˉrf!?^W	*dy/)0޵^(#Ԋ聛\"~zQJa*8uŉap>M'km^\000$~6L*6ćTo'`eL7-`,Y\rƷbČO2xof:GpE5Ĺ#=A)E(A:2T!0+bA&0&5 cC'c({MAA]6!_:rEGVN~QBd΁-ȖDs\nͨ3	Q-jsh;'4vhVuAy1_Zy̛Dw\"9j\\LNSl sNU)RJX}-hM	$*XD5aCd5l<1;҅hkAs4A#OZ hA6pA \\@CLӴ(\000y;\000fVsTV\"^ $gYpxfU,k`iV!ʻ\"Wa:հ%<͒ }a\000pU XH.u<ZenKXKSdLEs v%hrU^퓯B*$XuX5VsCpgVxUZLrmd2DgodpUYY-g\000cwaXB",
	["The Twin Empires"] = "0F#p3\"JA,h2 s2G#	2p4X@d4fH%g3i +M \"\"&I ;&ƈps3F,,e6\r&㡾4eѶOpo\rS9dΦ{00NF鋝ɭq)di9_C9:lfva)ԨG-݄^ ]ez-2Z릛Ĝip+)sNz4;d)4H銑ի,mlskDөm\"y,`@g`DityE6L<insa]PmF50fG%\\r` ]T[{1wFm-E!*WW4t^GaaG<(.>uFOV[mfA/TGXEVD\"JĉGu[B_Fdcԭ\\yŵ)T8wWŘ5-_DWT-BzpNDGQeYJvBhUޒQfo62ItDt[Ptycc\nEmdmtHb]X m'E`ԥB;!kDieVܤBD:uagX$AYTa`nQF6_X;fQGacXIunU4uF_	O[fw8'UycP&v2VG1lQiưle&&7A`qm.mLapnb(\"itk|4dGbJ^Yv]-KAt\\$TԎ(u_HlQ!.aFq[fY=FwR}Y_ҵ\"s1zYKՎ 6DwdƠAk$,):XנquԩѳyH<2\\cq}. =O4}p4iOމJ$u01\nv\000n@e]EROkR&eB'h`BO`(ke$vEl'6$]K0j5N@7 hA$໑b/@\"<si@ЈE(Ș'(\n]kC\000a#AC'3P_<sa^뒐CCBKu3dz#!@&_d/qk\n	VCDX\\Kon1<M?ǀMx{ችlRb̓<ʕ@j#%yB",
	["The Schools of Arcane Magic - Abjuration"] = "0F#pDJA,n2\ra6gAn7Aa1\r2|@sE&#QO,7\r9 4\n#I%L<X0)MѺ!r\nI#ɨzuLd0	Ʉlfy0Χ`K)T0CadM2وa7eJu\\dyTsc<瓺1q+Nv\"]\noH  z\npoaNf,W3e;wD3yEcnqD5Mٴtt6lIErnrGxՅmTFu^aQ0ey{dTW\000D`	E-xIL ұUty`QatqWR፛Sw^^dQuG&vg~X_pc!Sڄps^.BаP҄8UvfA1dW+&$֤ygqZfQRA6'tE^R՚KSWF4;l1i^l1h*efI6|r_%d6q\000WfIxwUrI.ޚG>XjfN	Ed7]FvgT[!uKa^tЃO!q{Yi~[~h9d*Qu^9^;tFAEoNbʪjn%6U٩ވ)f`qk5an'Ep-qw<}uJ#G'ނG,tt1$F_uxsLyUy!)u`Xiij:a[ê~*YpĠkzd>G6uӾ\n dRdQ^`p OL^d15S>̭~VcF''r 6G2Nɺ\\h JL3@Ȃ8̅UnÁ^0]T B>\n9[s`mf,5\n+B<\n+hm\"\"d(۝O+d	6j둶ȣA;2|8edl[/%쾹eVR7Ӡlb#-0{\"z3r)F@{PXd}.FTjp?/9W~tb3\r(JaÇfHP3-,Xs+%7vly!o	SaR\"Te<B2[Σ;|&\\^e/\rbO\\B#DN#MNP-l4)\"L_:@܁:C=dhe0Ă~]rGh@RąGfl5Ҽg;%9H\nEH2VU",
	["The Lich King Triumphant"] = "0F#f8\"JA,u9㡰  	X D)@a7i0I %MxHi2Nrp/ĥ#Di蔨oQ#l2N\npi:h3#y@I1Lg#y.*\ne\r&S(:GfS`h:Q[(2P\"V gseaufwvGdi ciykMH@1@s6fG\nAŷfrFLB1KqYNftapwma2SQFNZ4Z\"fD4Mx`zd&aF'u1hPàQwY?NĈmFqtEեU'P#TE1xǕ\rJAxFdJ!%5{ApPDH  Vh\"k=i[D XG1rT|wPHY\"qǅeKxLtZ6ieJQٶu]1BZEN4lu|⠂We$j5Uo	v'D%9HezpX$xcT_Z&t_A$\"sGEf9Nu\r5E4swt\\E($2a6b#H&+5~",
	["The Warlord and the Monk"] = "0F#rB\"JA,r7DCA&e6\rci7bd0n5ǎSdΧAdxr;O3xT@b03Veɧ#)M7ǎYpōS\\ Ex@i93Rm<V^Rl7HJog3<@g4-#)r/g3	qK9\\tm4\"i@f9efI͘:N<bkh5擖;n{Av6J&Mvx.BcHY%_%}li'a1':7R6r/aqy\\G664sDFTFuQ dLrgGF9]Za!xa[Y&<NFᱮoINuuTFLєa\\\\'aCgQ=cgs!fF VƖAV 4Ia= sc=}N]U%q)lJƜopJh87_$6{1I[%Y3Y!s`KRfqWcf_S	qFfQ|le	JQQ.v@U\nu`l)AOކ!18n`\nr،FpD~Lj1PҕbNY*iFl!ouUW,e; GVTǼpKRDWxmŠa~Ba6DZ8\"E=QiasY:1ʟ%:g#{%<hFL ȟa]jg=[r6m7cҁ1of{zv( C	HRha#o0za@ vEiNSz#\\Q?VePWX2FbQFYߓ3>=Gd[e]X)y9}==E/$DOGqpY>c_Y9IE76%2,!6gIS#d:pDE|<(>+:IM'\r҈a'|\"DI)d`4H\\}Щhe$yؖ)IGrm᫝Xm@({C@;zi	(0(Eط;Gza'콖QOEeBu(G	(r2KRSfgԕ ĺG2\r3BHVdn\nBHXO\r8T8C\"fcu*ބy,pWܤ`r	(똖e\\Q*a\0006ψEܿ`޵XG\n@`|Ah[',@JkK+Y#Aq)_S#lГ\000N\\b78H(ڵ`sqSpD09^t%g>J=$^$6N-yx]O*rK9iQ!09&U*=4&d:VP`0b\\1a%eQ$G@fЅB!,{ r,;&Js\"[P,(",
	["The World Tree and the Emerald Dream"] = "0F#Ȃ1!Pe&sA@e6Cd9qu2Ii2u9Mm9#1Φ oCII9P\\r6QJ(@A9X:RcX&3G	Ef) 3U3)04l&7Pr3擥B*4ꤌfi\";M ,NF=e6:hcA~ȝ\\Q9Ao9ʰTiyx-\r=+lb#uNQs`ޅQpw|%gR@wi>B␤\rHmNO$X_F4camcQh-3kUeaZW|i >wGtMؕ]mk9|}T8nژmqf).Qfx \"]!-avZ4XwUՙxVBiQAPT1dd^ֶ[ƀQSindgb0uQbTQic癀RX8u[5m֦|6)zquFbHbؽԌXՎ;MhVY)\n.5eV|nJ&wEtVѼo%4IEjQuA^IhrWB|5CTNTiTW1EhmA5+EQq	$EE#i_fBvx{d*}.JOɭTQve㉥0\\aGIh.yu8rG''lOh #`\":D6'JYG[ur|4)x[[ze13OA)QJIލWM4TR%gjq|it|HCyu[peGoI)&񋃞W=1Eqeqj5~3)z'e[z.	t8 \nHnD0ZTM0A2!H)urfs	%Œ6rK k\"0ɴv+Wu{/5J5AC*{G݂FIV`©HP-(I\n-%@ZR+پwk0&l]RÌr:'\"ykF`Ё8G	1\\`cCҺwRd\000cZQEYAiSZnE!#-HòC=J@2<aqg\000{#9.@Yq\rimDifTI?F,K*S`:D+i5 \n ۼi!\"#yI[-~M#3a,R	bxCi۔>1ăQ.(zGB*1rĠ/f4~	e~RyotrJ9~Y`4(>2,j%	W)Jq-90jJ}B,q><Er sdR2P",
	["Old Hatreds - The Colonization of Kalimdor"] = "0F#Ȃ8JA,n3GCt2\"	i9MuFQe2\r&.t6KFXXJ0\"1QM3L@w4\rA cg:y| 7yf\rJtm{1\\ #VMaEx*RȕA\"\nOd̶C}9M\rla3FcyS!OиX&v?!ryX*m08i1SZamgS$tUSIq3M|VÎ0&S7N!/ؕdfFq~4wr1{R!԰pFiXpl|SHD5PaL`DZ$Fw0_cT5-ՉU[CZu)Uq1kjVcHGN\rb%)d-%IҔc' dPvg\\ug!Z%aEiA>VdPd7QmLEqrpaMnF\"ѕdt~MwIuI1OU繍YQG͏RK^\"\"̤BV!dBc!ur>vI>LF&\"V(\rev#bxY9}0KHa_ۈѱpQLiToDQ^lJ \n$Y&LS \"&yAD肋@KYoY8kL|\\m_āv]9U!2[յRQ{.HIg~@SbHKivDҵ#!BK,OapcY#䴑&REyLJBfTF^f{Q,uާ M1bѱuS^jDJkZq/;֐|-%u4rkp]C~~kLNK!;*8:!Z$(%^tÑdx+!m(8=#Frl,XT\nXVm{aC%8.*{m䴞J|^j\\%\n@fBs+2MI\njK`rE\000eIC}\000^f\"δn*IbN.d]Jm'!Þ^!L+Q\r1XZN^+!w%FJE\\mjh;XkkeSɐ\"\\O5`q!{Q4=4%Ζ[VYVL{QN#cĜ9~I%<4D``p{Y$ML~U'=>ƞ+dP%$N0dN.i>y5LՖ[L-rȐa1,x\"T\000c3ȍQBd1:HGSȒyKɯSZAȷ˔DD2Dz$&a6Q`D苝u,`h\\D^b2\r/*lNɌ=(YK:.p2Db[I(-Jӥp!E6j`P3[Pef,|͇24MQL-D% >hd7VțaWtjR'avDD\\(>Q|0",
	["Archimonde's Return and the Flight to Kalimdor"] = "0F#ȊBJAT4DItMc)@b9LfS 6Q%3αhĞ$B:8e3M'Fhe:NFItJA\r)9$fT ǩ3I%1̈́xѰ@o3,(sdr'3yHI7y%*]RqTlޢ&cE&@U3\r'SuKl9Nu2Ďcfn^\"O6yGM̘ˬQsc	XtBc,hFI*k8<vd\000bTeb!i6 Mz-aLGTK1eRobD4UTbQoM& Izᄹ[1UHTW$JQG-ǆ4aѹ|Ue/	M%mLiVI:]e$	gB&SV!Yuz&	9u8RGZgBÔ,C[uEibxnNUSѵ!erji 7]#I#aFz8e-QOa1[q C	DlI9U&RpI!.aq㶔\n٤\\jcc\nIGi,8\nI-{ZA^юIFmKzYfzbZ,EQv,<X)Dc]qEGs&\000IFKmLG 3PPRw*oFNiUJB^F1wWc8OY MU(XnNmxv@A&< ]/XюUtT]ZKJ5Os6TZG?^FKZG1'%m)t,Us]as5vSPX:b{n¦DϴeHsgdAVDX֒25(\"<k $#\"W,5К4F*O7?RNVyW~r?C -{7zUTiHl82Kz؅2<)}CZW5Ȟ0QkA'ZΏ2Iٙ=9WҭQDMF3nIIML,N^H34yT84PkHu# s:Rh;*uo\000nz I7gJfN9kpMX,bAVWD #\nKQ&1aF5!V\nh}`̴_:I'[(S5{I#-tBEI9(Ml)BB&xF>IEkZ^	e(U/q%=1ìvd~o48JsL<SN\nĚ8`J=E2%pj)1ý7*LB(@ʴ뛛l\000J]̯ϑULPS@YYE\rج('!d%5*/	F?8BQAFȒH[ْ\n8\"DCDfVEԐgBl%@͠%zKa8Ϥ?e2i~GqaE!Jb-@DLҸz*ٕy?g̅\n5K\\bWB2lo#XԒ&m$GJMfT\rK{F/H@8LzHhF:KH[Q2^e%a>SjP&B`U~\"A$$wr$~	KޯR,7!`ȅasxlECE \n<xI,P̊`LKܰ0yxAEIJF!5a9p`	V/	ݒVªl-9''\rAbLnLFs@3;\\5/]B1Aު3IBόI[?LBUM\"uW$'i\000`|rz8RdBY@:݇uWWGz%),yMwֆQt~n1RփpR@xukryY4D\\JЛXlZNo*7uiʶtlAmrk\\z,Er1e)8Ibp6a\r\";Q6l,rS6_lHl",
	["Blinking Rules & Regulations"] = "0F#Ȉ9!JA,b6CŧЀDR2Mc	@o3	n2\nanFht0Xe7NQPC6e 6Ldi8@I.1҅D2j6joZ	+D[K;Nb$6#AA3ckeeC\000@w4('3l@t4O'@e4)):ӡe;O*ڬRwOr)vn:RrLr 6Lq4FqctI\000P6\nf	ANhXg2c3M[.O_&ŵI`dehZ\\W4mlFDlZGdDnc{!}`wTU1oX5-cg	!)>w,7C\0001gFyDٹfW QM`LRNYQt&5<STigam[0r8`nx9ў[z(houVVF939FFՃe'SedL1khqn`SL]x-b]9AJF*hƕ-FglcQAI9Fxed4\raiIuHD1U]&IWhJO5|mw_\\)8 G5U1UVR!Us_p)޲odlvj4ҋ$o#yH\rMknrZnPo$Q!o{iPgqUrUQƅ6EU n7]fkFA`MT6߈ԇ6YbvKX.vza\\IƝCh\r:j`::žLG]md,\\g7m%74cmlS\r&1%%BhrN!᭱l9<5Xj6oiYPmɹȜv\ru>Ddᾘ2QQ`(B\rHXRh2*	x'1ϔ5bNC3	e,CS'+M2tD	Ze8<UC!;xԘLqlAH\nӐ1,6\ndְoo\\1	4*BL\rc3U[^,,oJim6]K`!t\rC\"b[s:F<E3nmlV)qPy#Ԏ}Kh9\nywo|8BCW7E]x؀/ٲ5DgWcq)33d	i?\"08NraSrBfl!1\"\rny\"0pc{!ST!M-pH|JRwla$SܢqjMM	g*:@<hQB<I$cI.@w@Yp%:)\rq*ttNl%3BBA*4:F`CɃ5au#]A&(bgXd->´I&19aD?g ]z/i-&1J]כ9Q\nO\r|+=S!əJd1&%v[kÓ0*D\"vhT˄P[\n0a2sy0KcW$El[&jBkiIeNtr̨-EѣWt@d#S'\000Y\000da)1pJ%.)8g{a<n޺0r9t6	a<T]\"jI+-KvgN\r?{uiJ3G@5\"DgǷU<7 5Xpe;# `'Kv_3$:	QZ7aB6Kr':[V#q)š:kp#`XtI}'7QKOԪ $nԫM`\\H0թ	NUQ-0UWI6CV%D/s)|1?9!46%s{(\r\\#>-.16&.hF1q.-S\\	n.:SW-h>vI˦W-GN,4BBLR4y֑%=dQF	ILT|!'x\r:H.aO8S8uYz/G^үdwn3|Mxְlj2x!\r	",
	["Kel'Thuzad and the Forming of the Scourge"] = "0F#b2#L% i*t4·1d2)O:&AC2L 2bf9c&YdʄniHDd0badre\"&SȀx(\\H@p9g) 7&mXa6NZeg4GceDɑ's9LL2 K334\000 =ͦ)rrҦuє2I4U,vm+ؒ](Y'~vmD	ׂf3y3IDǉ=\r9yYPH^hsy`hFYFemxBaWׅ|'aC3D)HAOYKAɥ]aSŖ\000qrdG%!]DKn_)Z^T(uqfegGnOk~N=kնnsIuG6Pv[!CC(Xd\\gqp֩,EUZtUFQq\"]%Jeniasg}՞k\\eGUF5s4xsEՅvdk٭amHTBP1P]sToPcWvib6gRM1ofGE\\tqHf]ybHqaIő깛[fۃS\000qAbidrVein9!	Ǩ3Ҕ5MTs_]96>*IdVZO<XdHQLleGEMqQIK$*\nH0CU}bVٴo}F1L!ۇGzle,mqyaFho!VPbU翲pI|kkPr\\:6Y(E9Գ61aqo`mIGaPg\"ɺp	e	L߱#Y\\!w)L؟^#TjX{A+\r-@J?aXtiҔa\r|=q =vlH.*G94*aVM/Ԁp$25XfC惍$NC{(fp;h~˚-@d\000LU-ɀ)᠄@ژEfm1qH7\000`N-JF,&K\rń\000Y^nn04`Be#\\y=5pCB4i	/  *9'\"Sa\\+ЎBr6jaɪwC8C}tC622b]rRZD7ɳ6ȱT%R8yfIdZ)w#J-̀FPqdrZa3X2M?$	.LTBtC$Jż&9z'U0USSԛ_TIZN5',?(O(DۜϼJ]'\000I,SXe%@ee%=$ٴ<385C@*z*˚\nb-mw1s(OA48Bs.lV_jV>M\rǁ :(I;$7Bu\nK\000 1BpTJk6ON{kC+s/Zdl)b՗yZCsfώ!T:N}@:bfL3?P<9Ugê#Rhtba8R%~E`xS%uظw%rKs\nJ2&Q:U@̙d~xdh+LҐ&@;ܨAτ6^`#XBHiƶ.{g6?p0Z)0A+@ȆixUpZP`!<!\n~bOmS3/u<tq94@$agH>P0Ad$hUYi94`KH1D/D!h)A4Ő_JyWgZZnB)LrJht4Qu:jVBu]q[Eu|bs\000hS16r?eQ^TAj)$RA0Sd:#w.ńv.v^WEpDp&&7:`\r9$ڧ_cnPƫDc!1HRbWX!?b6=K|\r7cD\r94;~5	zshiH\n4 є},̻QLT'o(Vjo.)Rn=7?!8WW^:j\nҫ\"d%ǧ}̟ƮlYva[&HweH?%,)%\rR^ǤcAKdNsOyS\r#H#:d֩u5mA\\Yˢ=IS#6)đ-E'R&f/nn$q:3AQ%-W0G%r\rr x!_CwFVvav\"j`psKa1O3a[B\"\\\\\\oxhEb}BgEdBw7rQrdAe\\?0,X.Ф1$; B4x`idKplbZ6' urctIjb*ĐC{b8!wQ4bB1`hNxo0u677`.\"1Q<f^haI )(USuH}bU0SS\\De'6:wlPd3+2DoBh!27)0",
	["The Archmage Antonidas - Part II"] = "0F#l6#JA,h2'#a3LS6dM3 :3y\":Mf3GIBn;d9J :Ddbc?RӪHr7j1e:D0g5E:Qr7M;))DH2lxsUViB_f.gSd/%6Ej\\ %dFDEAh~JrG|>@bLrin4d+@\"1f7M`иXB:9O ɽMjgz@s2eܓhC.Dͮ6=Hv+^vM\\t$F!:TWahc!pc7Euj9v{g(RApD@5wpqrDLuєi&!~shFMFDmM#vV:UtI=|D^1qݲбUdeF'kSG8ixulH d%hĹLTffjA>DOAHSg %H4cYEIQ=*m6$x-~EQte~1P+1N\ntn6okGAqU~Fɸtf5-X^$v	j؛+Z-ŉ>WTPpciRA'~'Ri-zFё:YD^KIM6f,Pn+ kM}OԦGmv]M+Q,et<u|rFHTIeDu$,Yq6I;cIt\\9eUF5P^GEeyAelFh~Z\000D^7$ G^[y_%NJ@F<s|9*JUсFwiD]bN{R) 0dSC'4HqiQa%F9#URьk2eqb}Ε`;<O\000Am1: _а:P^'nHɂ[a9w&ʓMM{$\\\000	1o1-Uz$$",
	["The Tiller and the Monk"] = "0F#n1\"JA,h2\rq@s:NFS t\r'1o6cQpDW2\r\"s0cgs)ʌoMZqtd6G P(o9V3,Rѣm#N* dto4҅иXFHhJGV\r@p\n-N\rg4%l	egGf\\W(rL5 7cIfI@IL&zͣ+#f=cGݢՓ	@tHc)A!gxGc`Fty&Yf&J$sGSG%?D fZ\\iVFDGQrF݅l\\BtѐrFԴSIgFvrUYKDQeVfb7Qg)ވ'\000nPDsu0 WKQ4lF5YZqve,mI1F4f&GYaEtY_\000_sTiGpFM$^\\iYoY&QoKPDt9CBgeng~F04mЈVS^12QcOso_$HD]'rITvxuXDQFjnuAbRPmDniƅ< m'HM`H!SEJHsDjP`b[lSdZ,yXקmȕ^)FKU^]V	H||_	]$RV%ܩ}\"YtnX1pj/dCLdlES׶ZvIF~mɌOi!YgpݑYUQne =z0-r5S%G>*)xee!oha\000BX)	ʂQrF.GƔSf~|ON48I]>Gt/iTO+\re\">B\r,\\r'!͵r2m 5.VwUAPF582@mi9D5&¤K0mHb^B^/^ifUShS^+E[nTIEҝad+,#Jke$\\X",
	["Kirin Tor Monthly (May Issue)"] = "0F#j9 JA,:D 9LfSqyE'#!:LI :	n3x#dc8d9sag4M\"(@  \r	e2fӼާ99Φ9ri'InFg|t 2QMƺM02|^caZmfJ^dn5o8b8d1%\n&{|DDd0i:|$@R4\"2jͨAIkp: M$qæn7gS2Hi;Lj\\c$hotaPTWR L[E6N i%KVI[qaR G2\\!#&5$lFWqlqVDDETvW	!ZXA^ErJQԔr@)VFQ'a ZM&eFm3cק([e%UuZ<us\000oin8R,L&GqtG	=Ga7ch=_THsU(s|קVOnlRT~aG1HFeiKi)$-nI[!,IBUDQǹ3FFhKtxpE&|tYrHD4aQ(uz\"\nw\\aҊfjuE\"v.\"񊧯^w{06%mvn!-gbqY6V!~hfm[(j<aW\nti1FtEh?\000~\"%}V_aT`i6q/ELY%A(}erX)Rx5aR쎘qa_'<ќ2/,EU21J)].\000o$:yG)|?sMPfC>QTu͉VhJR:4H]:\n8a5;.>TLy|oe%͘C*Z6DCq_j02yG<B",
	["The Fate of Apprentice Argoly"] = "0F#jE!JA,'2\ru10h2FȜ 4MIPi!0H3yk8Efte6̦Xc5ӤP0#)\\ $Ǝz0S6ǥ1	E<ǍXy'C	oWD+e	a9B!6gaYB3Mjm#|2eՒ~rΘmAk9_qk$)O=:}a. 1ʱY7.|#p\nƐf}\\K(QY-YPENրpptkH\\᭧jsUqGqW!Ѓdai_ځRym!-nӡ<[4j5aaD*FdƆfF8epvH^(YIHM~MD=bG_Qzr9terKieH jqMӖ^ɭ)-o~&uх-Iㄅ?T	\rnQpy(fw)tV]*lqBpaW,iC&駳yv\\hlx~F$DeyPWMaLQFYc`-DgLehdZpVTANXmBI	\"jGx#\000cqjajщqFMƙZ	)C\000-\000EUsTrkĤ>NlWii1~FƄiZ[b!jpRdFYAm	!ҸjG%uR&=a9\n\000IJڈ'}'TIuQ]-Hdi}X\\դVcdԑpby.VjzF-CtPe1L¶[?b:Qb#Aio띻d\r-4MbD˒E 1!a!sMN{jJ'T(\rưMOg",
	["The Old Wizard's Almanac"] = "0F#d6\rL% g&L	u9 2#isbQH`@h0Il\r	$i1M	i7MO\"\000#4rNQ 9V! Y|o6\rz 0RLv	5X@i3Z#tGFzDh2D0X:fk!e~_;|yvd]1aL惥jc:^i2eaWUz@o&931t1\\1p4+W~ЀhSNHڵmf	҄l1|UP|kHD6;bs}0L!Z eYԄecW%} ԁLe\"}BZY!%V\")?)IvQHAdHecrU$tӵmV8JrpY	vF!4c'Dpj1$0G$їFiHJlGAUWCx0cYQfUAgZcI\"wuZ~H*L{dQ4Ӕy84Uij0lF79PmJggEvVUaqɖY$uZs]W&`	F(oܸhFo*艛Y_'}_p(T{zG]$}FicY.tlp.KG&e4h,^ci441C3POq\\i$ F6-SxCV9}lwSuntHXaURlG-fG4`v#\rU)SIp-\"uVqv]MІWX.WIOA\000KqWvqEnrӴot1tfdpF9SDAčdMWNb!XC\rct~*`;@Q٬imߴN/sdaL#a<v)0\"`6>\r}5BGQ!8DV\nrIemQ*\n#gs{S1\\BvaitNFSi4GG.rgZ]0*Ҩ-&>uWarHnI(eZC>r~* ky!'׋b*\\>a	%RI\n<'Gэ9iP#J+%%~4)VjbbHccl)}NElgPџmT8|\"bPF)E1js\\ʹ3}Q(<ϢKl,'HJv+Vh8Gd}\n	h8h\n\nSj Mc(n耖;='̆XEU$a$zI(Cx!in?cA\0001-!esC]HʳqA\0002*кELxrj\000l\n<f!.9k'TdLfzJFa@b'\rehLPLbErYҭ6:g΢K~fgKbq8m2A<VcMlr)ɬ\000&ę}Z,l*2\\=V&c)۴?E4&#B2|Ƚ]o*GGF9`*|φPąSE5kb7kѰ6&ىCima\000ʜIÒ<.&.M\\6-i)BS[!諾+-`fKsOl9å\000OѾxف\\0̩N0aaHZ±}K~?EN]VnF<$tpi~FGQsBi.	2jkmIA\r`O0؞JӇTJ.Tfthy.2scMRN4W,<%b%bnT]R2A*GUAJ^;%Hc5Tʲ]YbvzՆ<[bf;;pebGFlfs2Hݞ~\rÁ`+k<yC1%:.)%\\#C-&t.{pZKk:M:%\\e;^43eY{. \000'2p6\n=PRiR?yevhJR](HՉW+Xŭ$##+wf˫>$i *¾twB(U|\r+Gx`OL8lY@y<B$\r92q騰CЪyІ\r9|SB`UM;\"wĨ<hhNUS]hH:~k0}@~:@r2aYR*4!%I6MCg}'$=[\000cHV{g\"0(@dT`(qtab\\Q$&Q\"ABdb~p'P!!$&} pAYW#7'a4_1m#;ts\n6r:b& ABt\"J>%}qi: u1d-fOo+ZQ54u7wf5RCgb6b #5^-&v9IcoG9!\"a+2]5Fd!Oc<6U}{qqjP\nG&44\"b3#vV?<9&\nBqq488;\000x*qizAcZ\n@B\000Dh$pn.Za r[h\nwr8V%U`:b}rW*L~c(aKa<,&>B#I	e*!b!%6@eRDuGl-t4;,'#'BVo ,'T!ad/dZ$Pp6\\\"s3%*aAX40rw}(8,R;dCGKF^7R$& g'X0-\\  'g5F?^(BvU\\w\"GF@Viv^W!Qv9hN4+B[\"E5D1[F!? C`'qN&kqYrr!<%s9F1,qSʜ#2<!҇!)oSPyY7*Xd2H6r]([\n[1[ tuu4!;>IrI%#7RC.,>Ek0Ayxy!*s<2,/A|xA2A[B\000pFX>gr9rfshdvY&!(n\"#\n$0#VtG#7[K/0Kz'ps\000Ipq9t&@K<,radIID[>Gr,_EY{Wz%2dCg 8W(LOD5͑{N1%{V0C伎Mz{os(rphkpS[yBwz[#C%h#yxLha694H6b#_x@A/F	-<hD4K(49.dRH1A64ȋ]|>6dGcFWCF)t23>j*ŎQr RA:5B{9D+WZP08tԷ&>v٤;HgO!\nLԠ&ghFSV:Sy8nbuAK^F4~5)KQ5q-zU͚b?kp\")@\"JB>f$<Vb(:26jQpTpnY#RT-Y;Jh!+ehR3$gU^ua.9r3sF0hmD;BtGpZچ0NZ\\W睒ʯϻCS@p'yKpFY$Nqgɟ)&/;i-!Q_iCGɯ˴fv+It3N*\"Ivf\000y\rDh'4DP5e[,<fnygKgP^Xl_	G9c(x|\000.!Y4]0yQH;ӄcyH?QRu!'_(E]C$2bd!Bj1ji/Aҿ)_W!#Ali pg֮VW<H5CEC J[*QHᮕ.*&B!Q_l\"J?A\\z;~_1@t,_}	+,#vѫA+kjR6<KR\"%QtEt\\:̮nFuFE* ,tBXiVW->gJcME&m0*;!tX콘Ms#sWS'u5(C̶s'hdiX9V9ƱX\\*ah1S^睅2\\UBXtJ垽'Kb+V46N!M,<h7$x*wzzg>2D'{os`ARVaSqI侤|%2[94}n$y!u0\n5\nIP`ij\n|@f_ب\"Y=9{2(d=UmxڢV׺L%G܋Y#<2oHQ*Ŕ=?AhU{0*]O5!u$m@!$Eji\"O;淙)&CB+Hj0k\rj+%X$\nHS]mFzRR0w4'r0sRayCrQ9A#9} f@c}11Pr$E +G'X@v=ʹ?u#EͬE4-M'ht;W܁\nLD)jNԞ@q\nm<XJDk}޵g=K6jIӰFqC#1J2E<:q0QV8Xr\000poDvO1%.=J!*k޳1qh쪛f/;h+3myD=y;*gnP!܄?R#:!Y<3≏bm5U#lcO+e6[c˜_\\tBs:_N%m}o});O/Iؠ?;BqO5S-|55YKEL^4X?L=\r\n@",
	["Weathered Diary - Dates from the Third War"] = "0F#n1JA,n:\"4$ss'#Y 0(42	inIpaF9 $gSins/1NU\n\rH2L9$)ԍy:&'#<Lu9ƌRe3A4m0QoRL&ADc4-E\r[KwpMS4\r#yWLuS|Lr\r AgΖZk| qi)Sc?@u8jcFg(1Ng?eW7y\rphLQJROW\\u(kB-\rATYOg1ngqB&&'$mnaE_`SDQg| {7%QQQ. X3!cjcVK4hwuuei!GFzt詡[Yad+{QkneH\"dE\r!)I]eCdt|T[Su[ gXfDFčhW]kFE&FtŴZInuFpU_h{%: i,UFim1ұͥnu9{_#QJd!b^%&n3{bEyEtd<ʒ*ZUZ_ W`X6auw5ϯFpawj_Uukf6FʄtWnb).[8aա#r$MFVnr湏oէvm\"x^E1bIy[e 'v nVڸ\".n1R)^)(Ԁlqo0 u?:HvT^Tt\n cҐ10Ɩ^/Y*I{j2$^gx:vszљT<'pS}G줮tft%x[nfްBJ,SŔW$gfrr)-pkTb0f,R	?k(,UW\000{dԴyhaDHILȕ@+Ab:љ-3E\"p[!SfYt2jH $@ ΜCdVMB\000@Iٮ9f٫~C#18<(6F:%X NtqJ1чvOE",
	["The Old Gods and the Ordering of Azeroth"] = "0F#Ȃ3JA,sah:Sa@o7DMXѤa'De4	r9%a7D$)vc$Std(4LqЀE47Q)rǎsV.tX:Hm.'$73^ff\\ 9Ԩ醔n3)9s.SLlh4e;+#-><1@b_F6[34s.nl2Z'H^fYu\rSM7捽cqC I`d^ɩj1ZRDpVErYmH5}9cgcX<rKFpuoGpdRI]El)d-`_1u\\ɏaWH/QH9etSɁcG(\\!lgב+`|NYq_&Oa(!;yfQV54ffQaggA:EGdX) %QgsƠ}N$	QQbB\nM\n*ڐTր pʑpBs\\hNVR!FSE/ iDaRէ $lcFWF]{D,5!A@_і_/OxDqduNjFpa8Kk'D'ʆsy'{ŨWOel(ʟHAcFY#L`jd>Dg4W!hG6B\n5$G%(D%K]@oKI]sE\000ei<KSdMqRE✸ffKhO̦֨:IlQD^t(0)z\000˥&Y;'yɯxMưH\r12]v˗݉ͼ\\s>Kp+HKB.蛳txFÞ$#JϚS͸76R	}tkd6b0K  	,1\\ӣnye#zl/t3wҐ\rW$7M$pmZ7\\p,j5RN4C&LS7ɐu:|È٣\\&D9nI-5DBLyd2v\rx$yDEC*)p9P	9~#8Mݑ<qA=8rvCf	\n.9ɦw'NkGeFCB+T\"&I]ᅖS}<a\"2+4MiXcc\"6AS#WT@ik^8/tLq.8츧j	db7\000	!$f MDnzil:+\nfi@UhWҡ'd;L>ʊ#\"SU0 1!aTf\ncuV·SIl5&k\rhv̇eí^b&W߱:c\"'`w2a/5$`A+	$5Bb#%}IjVR%)^G	Y|<AWW",
	["The Schools of Arcane Magic - Divination"] = "0F#fBJA,h2\rS9d0\"Ɍm0Dqn)v4\r2h0%GHr2NSG%$YfKƓuo7o9*0٤m\r-6rNNF@f9ۊ1\"ITe;E#)d&3l3^b'C\"d2'~kO72ʔưc/\\,g$Iws:{ךP\rK798P,Fqc1ƪ~9PFWyV\000n!T6X fG5fa呶_E\\TDoiP1xS'm5c1w	1/ա\rX%nJf5aPB$,DKEYXLdDsGRQK_F^u	%RXV fmUuU䩬H%nєTtJ)OxF@,S恢QyZa628bDա<nmPcbĢQ&J^fkWfGn\nL^TQZB\"ѕ< FG%4m ڸ#4at%t,1BA1iYqDQ^RkAhG ",
	["LAVA BLAST - by Pyroco"] = "0F#l7!JA,a:\r&p@D9MƸќ@m:\"Ga@L0\"s:p43e9fD9P$'Ip(Sydc7LUhP\\\rEC@n2XL ʖsyC!e}b\ns1f2\"iI7͇S!-jC@@u8̴ɅdcΈQ@F=n$yѨofLٜCo7#q L3q=6&Ύi:s҉T]0L<U<mFqc~_\roGɦb d8eG!͞sFw>\ryZ־r]RmF vv=QTU\\hFbG&rnHXsIFQ6 o8-Gۃn%@pN\"\"RUXN&~作U`EAAP$QF&Rj	B&SF5Y}dtv0R	)|\n^\n@(gEt+Kg42pf10Y\\  vBYe9jy:&%!S&&ol+L_%guT(sRXĊZS+jڴi_J*:2B:FřW?q'GYNxm[w]hLG6kdfVP:v;8N!BDPlWMI&pxMUa2fUqYV/oKG9їd1Bq1Uj\\2	p\\\nl*RsIę[wЅaXBIZAєTSNQDg2_fu(uw~~I͈lq`LEfχT12J\n2}.UFUM*xsqfy{i~akO0PN0v :kqdfZ\\\"--C$*``yb\\4: iAО\"M,,9@0Xc,奏Ȝ:b\n,+@Jz;ڔ$Y!&f,9F+($~T0&ORW܀8fiR\r6\r##d2`wN jxG,l5~B",
	["Charge of the Dragonflights"] = "0F#Ȃ1JA,h:Siw2A`h2Ɠs8LgHb4 1'#<l@w4	l2	FC)n9M&܄90	n1EMF9 8F9 9hsM4	f9tOQ|e4RiJrMCnMnaYuAt\rh!$%9Lmw1Oy<N{\nh][\\'t&RG'>l)8 coHvjY.TYL}ѤgFbkMǑmGDL[C|ԁ3lxxl(]L\\w]&`b-de!$QK&]`d%Pn]EeUYj_4}!!Ei[SMt}&EW]ԑ%]&z\\Ul5\nEd.vJ@F6V\rST Yq{Z,cUv'TbՂRd`4ahQV~Y (H!MS+Ѽu6Iґl%V^Eڭ[JiiHrm\nD,5BU3Ua5%wZtoG<ystlWdjMU0Y!^k(ysԱl]Uo$FliFWD㦀lG7UrYeoFK|Q(.ܷ\rNUm$tsy<I}\"t_PMƕaX'fN΀[\\dBl$\r])%zVBqkQ%l9EH-zDiwaj XElEû\n={j5K}<-.ޥ3}aq\\Q}1Ϊq^KU/usFElDQ忡֔StG 	D7k¥sr䑸b+$nISW8TRY%)>cOK2Mpn=l.@f/:I?%'Մg\\X9J,xq,%!B!z\")XOhu}K%lRa61²-%.=$ynxRtXyD/:1>*FH*p-ׄk<!HXY\"/2HC2Lv_[wIA%3^O#I2Y!	h%Q0GLHK$1U](2nLxrnnS\r&CzAK*g+eLI\"fA\rS/BY(Gpc)ɶ}:(1$:ORXv$,+l>\rTLZ/^VԱ-fxeɑ@pC,︵xp\\1}3%M44i	ӅDPJdlٸz8\000ޔZ6\\TM!M;(ĭ&܉̈%+\nMT/%ĆPf$R\000",
	["The Kaldorei and the Well of Eternity"] = "0F#b3GJAHAMSqX 1')@s1\r	@n0LAr43m̱s@h0g@m:D4s\r2d<bA@W2\rzf2·8g0ǦF:P(01+y ;j9pV5AhY[@Q:cRDuéXn7ѱӥWcIabj<d/]~=n()N 6o̵Om7̣:WLfpIuL	rGt]|Ej:RyasPpT]fVe`vL&A͡Za ZF)ZX5BZ5bG!oeAu]ֱQm%[ i\\VQdRn<zayk7An\\!WuitmlfV1bynK Aui5ht_0wFln!FWRiuf pL5C<l^Q6œ\rK!GbqQcY{7S^ёKCL1B	_!ʦ^F)Ip_}DXfrjƶ\n3&y2k4u%mxpm\\cqveE5 HH̻Um9)c^6F!5VUyc%dșkRPg\nEygwP_V)LşQa/t9)\"KWFxMQUU^X&6X^1>kSWMhN/	qrvgvqH5cbmu~9^LLu\no4X^WS&87Owso8:d֓^\"7A@0uCf=A1Z5xCLYhq\000pu#4ʹ'd9i@(x>RÑ&%\rb[tNi|Nj7&.b&NJ@B=uof.Q/A0\r_*(fGW2]0(LCu\n`4X o~iH`ďLI	d<h\n#\000ձA$JKuń\"-j1gЁ+).W<Bߨuݤ7rZB@1L#c/01>RdЊ\":p)Gu붊21B!l͡4%q0!<p|y~ON[o(49CX$7i8bBi]a`\"^K!:QR#SN0wrv\r*\\!Ƙ\r4m\rŴ:RG*\r%$\rBe:؆'.Z@cȨJ=jFոa%A1L=4'~d行tdc8rܡJ$\000dXӶNspq4Dr%rQv3YIՙ0\rҁc\"+Hv9Ak5SJ+QܧS;'7_#l]<eda$NF4՚'r0KLPCi\\*t^QCFpAmdǾ6'2\\ݪH$­E#\r[&Laˁ	f0\\gEp8ڭ2rcR'bd[?kg!:|G l.ZpK\nAJ.a0zʆj\"3.3ozS&'e\\&f<]TcNq66gذt^Hbs\000Cf+i	Fj II+Yс *'ՆGЌȸEsAO[ǅ|\000^k;hʆTL\n2IEw֘a'4B]@G9Zndmmķ**^Ek) \r|A$Dh82\"&2%yݸ0|qf`2r^LSpISpDH\r?vԕ>K`U:,6(.4Lm܏HRX=AnZQi}dQGH|-X* d[CeɀLP5K\000PIF?:&-WC!+HeMhAP>SR0De85M\r.VZ6;&9BkF\"z@Sb/\r!THCĐVl2ϩL<TeE:+KNfVe-C2&ƖP0#X\"t.ݶ\\\n@naZ(^uBZ|&hb!)5LA7He0 M:1J\"9gChR-aP[S~Id\000s!]T;ARbp\\q/sIs2u-#u/H1+#u6z#r1*+Dn+u!y[4`b`cp?sI 280F֎q%Wh(\"*\"Ne5+$.!R]C-bHĎZH!9z@?\"ePXt&`6~#3c'|r, C&PF#-*`v3`@vL) ghe(!THZw3:h\000d%vnRl%e0yA|-w\\r8㎑;",
	["Lethargy of the Orcs"] = "0F#r1!Po: 9Ms̧(e0	:n42@u7LRx@f4uO(XAK1eQ#I[!ՉVm040ia ̧9\\EtH(+tO7CML;g:hqS	A2PLJ5\".fb	@C1E\"LluNՃL2ڥo'LUs:HY]r|gSN̆mӵ\r4]C4wsHs8NUөOP)rVRƑSY֩Or%hmS I]kMRF6U1+XZqřxrXwWF<M_rG1oѥ<MG%cׁgUE|T5j(4z/}WQdGEC_,sX`@ؤ]Ty6o6ndQdu&%UTeVn%~PGdUCde!+dm QkQ̚F}PJa58bm҅lVA<K9\"Q'FPnTX:hZT9^^7f)RSiuŞt,Jt\"Uy;jZHDFbD\\bFalhǕB,h^Qx!0L\n 䥳^Ɯy#o9R^AoWGDNu\r@s5ApDAKĺ	r$ܠkiǄ7p2\r5A=lZ0$JS<W;4Am=ǥO6T `\rkNtA<1WYa>uusZ^S$P-cF0~4j6.c.}`!AfY9.Lj<~fȁ(\r5J@S\rNrxcCkY$ZXmWP\000`nI\"4lr5dmI7g!l Q	\r&:#ԅJSAP\000I	6̊cS%F~*(B2mɂO\"7+(mP,9IiIG	AJp0jdL,\000dCZ!ྗV,\000JVe>.1`pFE탒C:?PI_:WI\\80Tz\\4RЦ|Ȫ)WՏJJg%@Vȩ n,R	T?iÓFBZA,dA8\n 'ʆ+B˱+WF-=&{Fx:`@K$U$҂H22\"l΄A'\"|UC|7UZyun=],Ct60тVThpPE< 'Bj99H",
	["The Guardians of Tirisfal"] = "0F#b7JHJs\rQn2'CI8Ng3)X #L'#!h\r)$@fqyFl(i7'3I !NTSq@L2,g4ΧJ^dP1 \n'S)NT4n1p\00078Rg̔@w4j󬒻@ڌbh7ܮ+J(e6\r5i6nh}U,L\rfS+MٌIk\r&yzdmufrGƩ!U&\"))eDfk]HqD5n& Lfb\000lfxtaoiQG!u1#_a_QF^|shG4WDс\\gFVV&WW+YyI5itҶ\000gUba9X\"\nhe]aZvbLQukq~NE\"j]Ncl}_uPdBh\000CG9~GPXTޒkYJNZ}PA_Y7G(>d}g5i_hW\000%7n\"zaFQ5ieH^:W%y -tHFjA(ReEb{z.gBmDwQuBKUdRFnoD1;[	DNlvڿ)];;_5r=G\rNR<#u\"]1EWj*MEWX]%ˬtA_Zx'D2(\\<gYp)wPMȆIH$AZFkOE/ӽztshXD۷~\"Xh]&}S^&QU\"QV4I&uI~QyDstx6Ta;}YVy9M%m#R2D IV6]J.|n'JiÊfC{B&2n]S5P>>咨th!\nI%3gσw௫cLWR~m7%0 L)h#Ĝtt'+\000aL91dF\\\\*FN+x*K@D1O7?4W+彇F]A*h`9<KV,0pvL!\"txKe|l(\"e >vtJ	CFoG3iN]Ķk#>\rA$q͆RJYM8Jb|0E U>Wbo&w	<\"~%\000OkeĴ͝R&\\m;n&*叟2edpϹé- ΠZwF,M2&*},wstAf(b:3ɕM3ZZ\r]op_K{&l_\"IA\nۉ̞IE$aJeehzKUg\n}Bɂy#BDˢZ6A}ٿC*x\"hEJp:BG 3Rn?s/HU\rJ\"ΈJىLbSi\nE\r3rvX}amd)g,N5?ŞLx4\0000&dK\"rXvX\000dj\000A7㚼}*nH\nVÝ^ZޤgRSNְ\000rrn-;pq܅	4U*3/x#3\ry?zȤ	qMMzYچ~˲&gNE-+CЎvuU0DȶkCV<Q,!5Ou}*Y\000y,NqYE*'a/ӡƁm$Рx:Hq'pb~\000ā	k\"Ȃu@URCvQoȢYlB.%ET[EFx/ӊ,;(U@Рa!0Z|Zm7oV\\8|rҽH$'R7YrKkuDEQгc*i^ЌFsqT/v҅˦\rsD^HE9MJݾ\"bS	KaĪb<S\nF$hK۷yFp<@>MdM1eO 4:Q4vk^T +ƻ*W>w\n6L\n%zjNhy}V`Z*M.Nxym% 3(p̦^»FB%1~#X`FisӞR1&OJ1m*}X55\nP)=_.8]Br6nglu;Jp,Hsmz2C6R4-@P9f|Q0[qr@hrM$usm{}1IÞu [DUq<gxuE!T[3N2B{w!3\"y%ERUd#tK]N9$w\"=\000:2uy\"aF2FIza)yjbaYt(uU8\")1Q!X*|+:3Rћpb9eY!AP7Q$!lk{sDURWie\"tRAw):a?wQ݁Uo0s pygYK$*m\"A{Ԛ2/!|8{'y!((9$oNY	yt[7+dtu7(u%1+tكH;h3?#$Ss,Ex7(I|8T^Ã\"a~C=yBf`-ru;Pt746nzA$|RT!ŌQ'~P'feaTmǖX!bt@~4xhGUla'V4V;UCG`&d!iw@8wAXZ\"iG.cs:obiHZ)RN:15%'=3GSaq'paf~6j8W7Jis+\000MFG h[r\nHE9=^O'`l:!_82ǉ MaF0us3>u0!-r_?yS\"tl!D\000}y1X\\Hٹx",
	["Always Remember"] = "0F#jE!JA,e2Mqa:&dT3s) 1)e2\"Qp/9r3AeM&1h?\"1M@l0'soG\"QI!M5\"N57#Q|@uIky\\ $dU	('㡾='3R@s1Imʤ|٣O_,#(u>lJØNcRL\"&h/N27ct Բ{IKXȎFL\"uIi[Qӟיw%_Pgs}m6LS1jkSqam`AAGAFG<fx֝&]B$9HeGQd\"I+K\\A4MAY\"-ML_MUEi5WWfYVp[\000oWusjgzcW`Fؖ-irvfalfT$i䦩krlY9nroB	QpQS0tsuavƽw' xPzRd)|hawRx1_8JajXv\"#)Tbsque\000r-t-91U}%FQIU`DٴLGGJF5AM*f9цAF0s_<nOᑂUNGᨄuQu5[}|NI*MkKl|ua	/I}M^tkDtSTܠ\nFYTH%/JG\\1D^U/Ѭ NKTFuv]|-W١k4!u*cO[z$YrET95IMoFyɵ{sZ{娅b8EX\\e7Xk_9ߚS]^Ƒ\"S*F'<+Ie#?Kԛ&u@b+\000",
	["The Battle of Grim Batol"] = "0F#l1 E!$ :u9E	x9F'939):FQi6F@a8NGI 4t,efy 1Mqw͆p@N2FATQf8)&gSqi1\r2Ii<w,Hl1$FySs*72٩9J 9ƓSyL)&c;M'MnnT2ޅk7J%FS1y4FeWk!\"e>\n>2TYbTbAlE)2PxQqDy$M)E{AAQҷm.`ѝgԡ\\%iZaTiKuMcK1!|MHRsbiQfHcusäYTU34axMѷXAuYgM!.RB\n%ۏ!\\Wec9>pd͢vVAR_YsNc$d\000Ȥ}qvSQkB(ա~BrhUi!j*HCD$=Hb6K FluXZj*jMf:uJ\\	ʹtFF`UK|E	̿5eٔi~Ò%>}r|uD|nw.jlz#ƯV[QDe<Hrb;_Ab^R-n<sb.Wo}6Nt@Ĥ^awdoYXp 1|uDQ{OGL׭$7|s{9T@F[{/M'eU9p!Bڊ[)EFDb7XfyM;BGw}l+jZ5G/iXU)DaվYF6IBY&03^u\r1v`FLil#Vt+ͺ2Et@",
	["Sargeras and the Betrayal"] = "0F#b1GL% g'fQLr3NFa;	@h4bI:wE&dMӃd<ȍ1l7e)5A1ͳIزO6N#DO)Fqo9DCG;GttfWDy@DDRzfOgtr,Һr!NF쐀e2 2ILcLs:h\nٌ>9I\"\nh6#u6קSj8e;٢A3>d>id2*^sA҂A\r/sPQpRSaFFv^u%1GgGXneLe ЁH$;tz#OVSh8dDKGtc[c0ߧuyFlJFD_FeY@tE5\\yQf>l]\"1{\nG1C'etvzgNvZL5f[t}\"H[ԉdRL&z)JYM%:GZy)h4	טTyޔVrumƸGQd%gGiKZvotPekb共EW69~[΍ceHyN8`!|FKj'axb^\"@Ga-nl!=;Ei	5ږvmc!<Ҥ`n&m!<g0gy{0Az.\nFIPaƮkVٳ+rLb%m.UFQ-FsDQ$T!hiFN<[yOmNq(9Ļmdtm1dӦo%WaKiD~s6\r)0IqUnO+A\\bI)qp8ڨ(M5% %ћ$Si[g%Dtъs!ţE {4uq-%U*9\nj&@1rKy<`ejt0ņP܊'ze4	1^H<&ch5x,qPd(d@u\\Bѯ0@hE1D]x̉a+uxXʛ Cśb\\%DO\n\r*s%5`Iw\000Rre>Q\\.id$TC%Fh^Kp+!D(-Fxp`A`DC@b7IBƜ$(AM5&oIMQdN;6琢EZOuhf)Kܩ4iHBNBK/Eey`\\k4(M1TtdRX%b2~`=)1u)C!1}3:0ز<l|M<SnyUWL\nDJ31Ll&@pI΄IbLyA!dQ2dlC%:KE Г* gԟPl#,\r9b3v;2sI2%$3sA*?d&U딕%0l38A%a$Rכ}.FICt1&&lM60	>d(Oºt\\b\000!ߦC-@OeWp¡7C85nۋ&/9~[F'7jC	1.dQ*\r;W3s#WB])f)#{LaAYG˩@UZLgȞ&Tm)V\"PK{f2@z$M\\)[CÌ]>WPbߚF<J}Diet(i-l5b]2N=`C^߁x4gQnZ5:5[*9+@\nK\r#2۴$%`w -=$2=UYLzݒPt<)(t&;(F)r㰀hv@-LŔ6FWJw ؆=\r,~CGE=Up٭'Xute!Q䱖/\n=4?D3?5{XNopD q`n9ܦ	̎y[@źQ*E)mchs&n+m촺|#!$j-\r`rHfXʵvR)}Q4M\\aMFU<s'|稜)C6ْSMw>J$Ft#\"̕/]P^Rк-)H6I'3\\R۬,G./a4>(d$ϐD\"6@NG%9$]8Klzo4N'9.7FtGJ\000qMfeI\\|[͐ռE-jj|R\\^jąaCk똵U\000ҁtb`#A$54b[b|2ld_,FҺ}5&B\ntr|afL2XZrGD# ub&%W",
	["Bundle of Romantic Correspondences"] = "0F#l2!JA,o73Iv\rF	!@R4L&q@h0C)G,Oai:#IA@n7finNyAMMSa9Of$rs-V,sm9$f3)\\ ,-bV,HAFM;Dζ!tb0M4#	A;kwQ,F)uÈ1lzR6o,7Ocy3\n=/M:qO&s8MAљufs#)ӌ&=JC[s]BD- HA,e%.mG!pj5o.tG6unGtXBMTvJ%h(?}GsPܱvK[M*P*By1GѼf_iQ]q\"eځuO	#f5P'8}mU{vrWy[gFĭdU<U`t!ad4Iq[)QMqцOfYK	JLJ!^\"ZP%S\\!F 3%(T|_(fT:HƄMt1WR_Wf!J]qqFHwR%<'_rye_Gu'&fcqjTzvyf	[ig\n;(rFZumŴMra'/R!XIqXV8DwJD,2`[\"	*t{EBץ'W!eRb	8X9@iUԵB|SNOHfCT@njn-\\Vbr2HDO_bdxXK-jVvsfېRs׭ο^Ҝmɟx`B	ˬY4gy4FǁNЙҨfPᓃr9L\n&]F*U'-dƆUG<+wQNe3B0#^A̢S\0006]D,g.C<kiVjJHbjR*wHd٘p`SL)\000",
	["War of the Spider"] = "0F#lCU!0f:l2\ri7̆hn7,#$I %a7#)rj9FMÙALc'za.$u\"u@(Htc	\"cuce9o9fd` mtȀG5vsdEnll\nE HT4Y|`1hS-@i6d]r3LwNz4E9v}y5wܡ՗mg#s2\r&N(GR'd-{]=sfU`^IfF0iSZd]JX$aaؗQvpaHo[pAH7vFTuWѥ_aJSuPTtQ\"3WZI[23m߈<PG7׸r] W%sK~![ƈ\\IYtW&xi)`eiՇQv~ebQ#Eᘦ1xQ b8tW0Pa	54Mۣ䅹W5S\\>Vo٤%fQ'\"ED[JXQ[X uG']+MSx\\XU W&%Vl]wo՗UXdFIqnqFOIG&)l% _\\Aln\\ջZl;k'ҔFQp'sFwPGTFf4ic]2dQ3q95HR;B2.g,ekfu4UdFpV e߷OǓVkHV]8EzɡgT8!/ P'Mk5Oiy\"1iTevZYqg!a5.I0JS:N#yxĄ@Ĥѹ=Wkd\\r\r\nS*q#\000ys:.ҒX12VUW.\nXwF=ӊRub\";H5ЃO)AftިCNg_M4W\000YR:c N(xDL\000[o䂉Wi|~1~Y]tUDNq+!ـ",
	["Civil War in the Plaguelands"] = "0F#j2E!\\a5MS @b:C)r6bfA 9NQsL'8,A9\r1c4E|>7I\raK'3Had0qaVd#a$2%stj,m	ڹ:5\rTe&:zn*jjat9c&i%䱆3n͘9IL)$XFҞBe)5!TpGbY_h: :aAAݦO65S7\nD=]ޅ9dT#o0=vq UaRmAZyԴrmE5u1:h>cgvvil 1uu!+'oGQaI$1H9siFݫR\\2)ggpbЀwGP%9E\\Uw7Qc[0Z$a~a[Z6n^Dtb\\]jL\\Vi&ٽAK=]LuI4(5\nѥ~xݔrF>^S3EUVK\\Qe Jǎ9Բxӵ%0f+FQ%dtEaH$1x4 b-h}oY;F1AUbĤzFȩrEݠ'\"\"O*t^D:Bw[+n[QfsG1epܾơnxlI6~Xc	؋oShU>zdufvіOGQt0=j3;h4\\},gHNgOQΝIV(yG]Xl$֩RKgOvDmߔ~j7xiBBNR",
	["The Saurok and the Jinyu"] = "0F#fEJA,h2fk\"x@a:I>nFi:2Lw7MYld#|\\ #BI@IOg NH.Pn<fnda39\\#)JD	Ea\\ b&#	0ob֋TNc<DoX&'c)]b!d&Ct9cLp.M( ދ3Y_q2Ctg͆SoGi_9&3ǗFS`*GqͿeYMkݵtunlADX9d]4EreM])wY4;1b! EFPB,Aobqځ#DZv`utF Yu&iTDqofaudaIvNgfG!tvetlDVxUnP W\r`.Q%%eaDN#LUs|lQ*}pqB{F!GUjY-T-oAPysUEZuإR9`Xrh z}Ɣ0+&|U:<aRم-ȰDc`B",
	["The Schools of Arcane Magic - Illusion"] = "0F#jB!JA,h2rNF3Ag&!!Fa\000A<\"l3nha9hSĜl2	PёPLyi73p@6LQ`c)Bn*}ta-us	vZE#ybtNxr6LguU1m'Y8VM9YW4dt;]sTWBsǍzMgD):ZʹRm{fWmƇ$hf&IE#iP{VIYgnBog_8uƀB4,CZGAgߧpMѦm}}eiYVw}N)\nZ/iWa!ksaa?bѪRUUgaXFx8O'RSr~FuG 䉈f$(rnyIF䁶YiubZf=`[`ܔe1j`PCf=^FTi_)T_޶RRS1O:yb-!LDWdwLEedT+}[iз4qY)ykR k]F!=፷rv>Y=^S{eR~KIK5eч4oԻ\"OH	qN2&LEOYϙmqZdle@^$Eq3YV%aXhPlXҍ\rDjlow]MQkrTe1bgaQ^Ô$FXZTaZZp>CQv\r}3VYfKS1ibq@Ȱle&(OfQg'f	5NW}ΐEX&~_x3*VUGw@At&RFVa_ ",
	["Mount Hyjal and Illidan's Gift"] = "0F#ȄDJA,o7̧#q :'As:I4DSe6I1s	uM)C30$G	HQ*7MfCe ش` 6RL.\rz,NM0YB:e14f7W<d^+F9#	iU3|fLٜ%M4Nb|Tlȟ-Z3j :1;DGtu4\r'3l:h%7PFl^-朏oQqoX]6Sy,7BısN2]))R%1vT _uѕsW6eQ)EX<u^F%iFEy^\rݕGm}m\\0ce9EfT(\nfWN&)	\rz_sR֔^'\"OFRVl {\000uj7E\"KY7mUx*Jcwu\rYT](_tQwUWQgQ5z+SҞ`E8pXFhyq݃G\rM5&ow\n&H_;mƗrJD,6BJe/Lk tt:)W`cgVo^DtR-'TEEyxxk>n+IL-HuGı.L\"Fhlg^J tMG:W3Ɓ\000Yie ^'IVYIݶGqplE$KY%~pmhK=_I^K%֒MJ_ז?RUOG6OhpeRFe֪Z|{8.j}nQOLsP2eYR`NYyU)EM2g\nu׎j٥e6GypT=]hfvyJ	bi$mRE=yhHF	S.$_Ĉ/6bu\r\"l<fY`mAA а, |KhFXY\nQ$]ŗP\"6UeÇoJQ4fJ*(7KS%=_ US5hH+Pl#T<\rmOar\"4+x'pA*grℏb)OIC s.1ۇW[K+1*1a(ȩ OL:F\nWDR\\Ѷ$Mt'`BG&ّh=St@fb+\"%$JHcu.b*mĄOyhuE`ZdZ2(p܌cmN\\& \\B/$Ag&[++ox~MbDd&Ӹ@e{ͼF1Ϛf6Sx%eD\"h1I@ӢTeFpe\ne;\rDwPÚ(Jfny)L\000C#~>>sACQ@H3NeI瞎W=2}Q0p+8M,ʀ~nWװRdқ	\rܬש̉KK6|!DIb<%CVe#BTmGvs&I:ጢC23Լu#5 (ِͬ2oPJdV}3DADH`*4.L7Vʵ9$ʠ.Ami@0VTi)$#Ȓ8m;3Hѱ)M8ꇙp#CXS[,]-%",
	["The Dangers of Magic Abuse"] = "0F#l8 JA,o7Ӂa9Dєo:u60n4NQaMs,Ba:\r\\A;GFCIi1('C}ia3M&%XPFY=:MQpeҩ{2ɼ&YgY57Lcs(7Ie)ᘛkY1NՑNBuqNUE`fN\"G#u\000I9J=؈$3CqtcHY&\r1~vp\nKk1<9 \\t}PXD%~_́t4EUiWvFhsGdG-{y$De{[e|ױ%\\es_UuD}Z9wQ'l 5=lK%M4zձi5u=+ui\\^1ePJ\\giU_&nWlkRQIDɏQt~5VJDV񲘡ۨ<lй@hFuoц֍FF!oK2MQu0(B..\ncq\n}׶SJMpdJ}W&ST;.@OԒ$JB@z4wE)7Pjkj=4]E\"zV}'V>ZE&tgFnua^azzB$,F`1:@ o)]~IhFPj>Ue1efѦ\"U\"w.uiXKPHWg\"(zO+yUzwҽNѽHN$pPp5Lޓ$Ec$M:M)IrEyl}NO͇F>y1g$HwWr۵eI%5=deRr|u`ޅB_u;i\"sts4V+3\n	a(r:\"\\YNA|ڔ?\rȽ>C(h<vCCDh$~PG-dUfB 6ֽXh\\@$ZJHqɛUD,",
	["The Scourge of Lordaeron"] = "0F#jEJA,h7Le@d4ǌ#	 4Maͦ0p7̧!`'0f6NqA%$㙚8m2ǥ2LH̳)No3Eba%LzYƘ.IM.u6jyCRpY2h'uň&YL9s\rwNMכe*!)fӬw7ZlN9}x l݋Lg#/&Gٿg-QmrO^iAlBc8^{@s	czeQdbF!L٤nm&\000HF!c՗ gFWŇ8uDZu$UDa~ZtGX(r`QFDPظ  FGAAo'N vYFR!X-8NB}ƙ:ht F؄xs`J$Fepo#Q\"w5hF|a٥kTƵ-hޅN5-G^GnO]Xы^iuC	BRF%WbGZ=`@kiac]m:pG5=TXl4ЫЂa\"9^Ge1 N֩](&\nq݇yYvG)k]KVjpMkoGQnv69җFQjVQpTFnb`qev\\eREKʖrCl[=uLױy~JD,1Ffit=j:U*}&4.C\\]{T6ɌMS\"|xZX)u0E,ҸxQs61$Pdֻ7edivg^e.:EvDʬ&V\000DYGE)\\fWэ9o.5#2Lie `IRae}",
	["The Sentinels and the Long Vigil"] = "0F#lBJA,h2@o3ai7@v0\"&) *NFq\"b:\"^w4\r󬼛)3NFy@aBm<S:t:Jy]#9Ģle7)F-9LbDL#ZsK!a9ZcM͍A(DsrSΦٸ/e[9,q;!T6(ݻze8i36K{K:Yyp^!jhٯp(6)gޮ?F_}{zqrktdAQɯ-\r孚tC\\9QaH[d!~ֱ4o[F6dKājJVq ia<NE1,eK`i-K7y_hEEtuSXj+D&z5o Di[2MVqSNBuPhAu`ǘCS	oB7UpfqWf@rd)SQoFіKĴiFHHd)V3MQeF${QwXft' fڨom!:'_UoY9gC:j]iњ$%^vAKap_7z~ D@m^F,$vŁu6ca%jsF\000P	qX]H=zwƖD(X&iT\nM#0#WGp jluddԧnz2C(eOhײºZD ֿlm=ǾR{sSSƹگ8 W&\\M3DGmYUH-M%f%zp;f<mÇ`bU<t67	{>!	VeMަYå[yvloF5uOw$,+`k)G`Xpr/fT)SL94ZO, ȳi!ZrI<rPؚCV$E	Cu/z\rY93(\"xϠ;BdP׾W{𽫔2/`X",
	["A Treatise on Military Ranks"] = "0F#b1JAxH*Ih(xB'1H b 0\r&spDc2S|E'	%2 )IĲF	Q R\"G.Ri@s9ęTa\nbHn5&C9bYA\"IS1EQbG%fi9΂g:RC9*ՊЊ+9W6;-k#XivW;aw7N/7M,X˘gYu6-[h[-qx^KbvT嗕tp>\rWiqk\\'pXg}r_~߷vgiw[8xe1H9쇡\rqoYmTaTE)\n@D%J?F4zbi.Oa$CE$:OBQe!JSAiIKrd'Fݖ$\\Z9^0o|\r)V(o=uIjׂ(8[p&q0eܡnYgGx*z0\r6(jD!o@Gf񒴱gJvzi6V2|,t[>8X0Ld\rdKFdu洲TibZNS?PT5GRT6={	- g7Vm⼷)1m{ga:>W컶ԙ\\#yC;(x.,); m31Ѳ)Ki{f%ϩ,֪=0icbQS5*T\0000sp1aG\ncP;N.\\].L$6{\rQ12NJf'Z-]v?wdфjrM:້Vn'r/$}kMy_3fл%s\r=GYn!p\r۶wދlmLPv$*Uג&P%T]J]a:`emF062Ӌ.ّ?zoRKYQ 9$ R|p-|U1pH8bSo#`/ERV<|O-DGb:AXc\"sY!$\"Hö1</ai}C@S#lN&|\"njn\"&N`/7ܳ1qG,`l5$(Lxe\r790\nט̒#2w_V_H\r \nB<A\\vhVY!,Ψ!;3xݣs^ψؙ왒P\"/	t,ZUPBE!P@\000M	$*eIm@Ή!rQ;왦4+&}:\r9\000كL:CI\"!<	xÜ@0T7`ATU9aPIppAY[a1 i\r9OP諉K\r5~ICXn!X*U*ܱFnV}X	.{@)`-SKRnk:VPB2;\n,`J ~V`@JI\000;pjK>J핒)K\000{a@Yn2kTi\000LRes+@i\n",
	["The Schools of Arcane Magic - Enchantment"] = "0F#jE!JA,h4DLa9&Ñd<ӱu9$&#) 6ˎcq 3QCLdkyj:33yX (8,e6	ΑxLn9*FC,{64iGfؙ 1i0,\\cf=_'\"\"-A6Uf׈;Kgn\000g4b{Y`̊nE3P$a9MfKYn4\\Nș3fSfyމo1hStSLn\"ulF}y_6SuǹFwiGvad7`vY[4Ahq=aļwERg[F`e<]febQ.vdM-б=aؖ-YԌoU6wG1Xvu;wV1l_]'9	z`Pё}c$tskPvxq&*&uVʀXG!pD'f]nS׵rѱh)iZhi'\"Y\\ՊgFX!jYquhE|iפaF1yX^1zhᅤR< KjzYbsٴUfK$h%	FDleD=cgYx&gSVKJNyIy	A :Ngo@\\	I1eVW1\000qw\000c(KykQɔņΨFemO0uynf>YtKWe3\"%MZw%n<Ytk)$HFAJL̄rqyǽaD,˥:7qwoznYuaՄ[:`!},b5PPKiaUbW5A q% a>B",
	};
end
